﻿/*
   Created : 11/03/2014
   Modified: 26/03/2014
   Project : PFC- Base de Datos
   Model   : BASE DE DATOS OPERACIONAL
   Company : Universitat Oberta de Catalunya
   Author  : DAVID CUENCA AZNAR
   Database: Oracle 11g Release 2
*/
--
-- 
ALTER SESSION SET CURRENT_SCHEMA = USR_OP;
--
-- ---------------- Creación de SECUENCIAS ---------------- --
--
-- Identificador de Temporadas
--
CREATE SEQUENCE SEQ_TEMPORADA_ID
  INCREMENT BY 1
  START WITH 1
  NOMAXVALUE
  NOMINVALUE
  NOCACHE
/
--
--
-- Identificador de Competiciones
--
CREATE SEQUENCE SEQ_COMPETICION_ID
  INCREMENT BY 1
  START WITH 1
  NOMAXVALUE
  NOMINVALUE
  NOCACHE
/
--
--
-- Identificador de Jornadas
--
CREATE SEQUENCE SEQ_JORNADA_ID
  START WITH 1
  NOMAXVALUE
  NOMINVALUE
  NOCACHE
/
--
--
-- Identificador de Equipos
--
CREATE SEQUENCE SEQ_EQUIPO_ID
  INCREMENT BY 1
  START WITH 1
  NOMAXVALUE
  NOMINVALUE
  NOCACHE
/
--
--
-- Identificador de Países
--
CREATE SEQUENCE SEQ_PAIS_ID
  INCREMENT BY 1
  START WITH 1
  NOMAXVALUE
  NOMINVALUE
  NOCACHE
/
--
--
-- Identificador de Jugadores
--
CREATE SEQUENCE SEQ_JUGADOR_ID
  INCREMENT BY 1
  START WITH 1
  NOMAXVALUE
  NOMINVALUE
  NOCACHE
/
--
--
-- Identificador de Partidos
--
CREATE SEQUENCE SEQ_PARTIDO_ID
  INCREMENT BY 1
  START WITH 1
  NOMAXVALUE
  NOMINVALUE
  NOCACHE
/
--
--
-- Identificador de Apuestas
--
CREATE SEQUENCE SEQ_APUESTA_ID
  INCREMENT BY 1
  START WITH 1
  NOMAXVALUE
  NOMINVALUE
  NOCACHE
/
--
--
-- Identificador de Modalidades
--
CREATE SEQUENCE SEQ_MODALIDAD_ID
 INCREMENT BY 1
 START WITH 1
 NOMAXVALUE
 NOMINVALUE
 NOCACHE
/
--
--
-- Identificador de Tipos de Modalidad
--
CREATE SEQUENCE SEQ_TIPO_MODALIDAD_ID
 INCREMENT BY 1
 START WITH 1
 NOMAXVALUE
 NOMINVALUE
 NOCACHE
/
--
--
-- Identificador de Registro LOG
--
CREATE SEQUENCE SEQ_LOG_ID
  INCREMENT BY 1
  START WITH 1
  NOMAXVALUE
  NOMINVALUE
  NOCACHE
/
--
--
-- ---------------- Creación de TABLAS ---------------- --
--
-- Tabla TEMPORADA
--
CREATE TABLE TEMPORADA(
  TEMP_ID          NUMBER        NOT NULL,
  TEMP_DESCRIPCION VARCHAR2(100)
)
/
--
-- Clave Primaria de TEMPORADA
--
ALTER TABLE TEMPORADA ADD CONSTRAINT PK_TEMPORADA PRIMARY KEY (TEMP_ID)
/
--
ALTER TABLE TEMPORADA ADD CONSTRAINT TEMP_DESCRIPCION UNIQUE (TEMP_DESCRIPCION)
/
--
-- Disparador tabla TEMPORADA
--
CREATE OR REPLACE TRIGGER TRG_TEMPORADA_INSERT 
BEFORE INSERT ON TEMPORADA
FOR EACH ROW
  --
  BEGIN 
    --
    -- OBTIENE EL SIGUIENTE ID DE LA SECUENCIA SEQ_TEMPORADA_ID
    -- 
    SELECT SEQ_TEMPORADA_ID.NEXTVAL
	  INTO :NEW.TEMP_ID
	  FROM DUAL;
    --       
  END TRG_TEMPORADA_INSERT;
/
--
-- Comentarios
--  
COMMENT ON COLUMN TEMPORADA.TEMP_ID IS 'IDENTIFICADOR DE LA TEMPORADA'
/
COMMENT ON COLUMN TEMPORADA.TEMP_DESCRIPCION IS 'DESCRIPCION DE LA TEMPORADA'
/
--
-- Tabla COMPETICION
--
CREATE TABLE COMPETICION(
  COMP_ID          NUMBER        NOT NULL,
  COMP_DESCRIPCION VARCHAR2(100)
)
/
--
-- Clave Primaria de COMPETICION
--
ALTER TABLE COMPETICION ADD CONSTRAINT PK_COMPETICION PRIMARY KEY (COMP_ID)
/
ALTER TABLE COMPETICION ADD CONSTRAINT COMP_DESCRIPCION UNIQUE (COMP_DESCRIPCION)
/
--
-- Disparador tabla COMPETICION
--
CREATE OR REPLACE TRIGGER TRG_COMPETICION_INSERT 
BEFORE INSERT ON COMPETICION
FOR EACH ROW
  --
  BEGIN 
    --
    -- OBTIENE EL SIGUIENTE ID DE LA SECUENCIA SEQ_COMPETICION_ID
    -- 
    SELECT SEQ_COMPETICION_ID.NEXTVAL
      INTO :NEW.COMP_ID
      FROM DUAL;
    --     
  END TRG_COMPETICION_INSERT;
/
--
-- Comentarios
--  
COMMENT ON COLUMN COMPETICION.COMP_ID IS 'IDENTIFICADOR DE LA COMPETICIÓN'
/
COMMENT ON COLUMN COMPETICION.COMP_DESCRIPCION IS 'DESCRIPCION DE LA COMPETICION'
/
--
-- Tabla JORNADA
--
CREATE TABLE JORNADA(
  JOR_ID          NUMBER        NOT NULL,
  JOR_TEMPORADA   NUMBER        NOT NULL,
  JOR_COMPETICION NUMBER        NOT NULL,
  JOR_DESCRIPCION VARCHAR2(100)
)
/
--
-- Clave Primaria JORNADA
--
ALTER TABLE JORNADA ADD CONSTRAINT PK_JORNADA PRIMARY KEY (JOR_ID)
/
--
-- Disparador tabla JORNADA
--
CREATE OR REPLACE TRIGGER TRG_JORNADA_INSERT 
BEFORE INSERT ON JORNADA
FOR EACH ROW
  --
  BEGIN 
    --
    -- OBTIENE EL SIGUIENTE ID DE LA SECUENCIA SEQ_JORNADA_ID
    -- 
    SELECT SEQ_JORNADA_ID.NEXTVAL
      INTO :NEW.JOR_ID
      FROM DUAL;
    --   
  END TRG_JORNADA_INSERT;
/
--
-- Comentarios
--  
COMMENT ON COLUMN JORNADA.JOR_ID IS 'IDENTIFICADOR DE LA  JORNADA'
/
COMMENT ON COLUMN JORNADA.JOR_TEMPORADA IS 'IDENTIFICADOR DE LA TEMPORADA'
/
COMMENT ON COLUMN JORNADA.JOR_COMPETICION IS 'IDENTIFICADOR DE LA COMPETICION'
/
COMMENT ON COLUMN JORNADA.JOR_DESCRIPCION IS 'DESCRIPCION DE LA JORNADA'
/
--
-- Tabla PARTIDO
--
CREATE TABLE PARTIDO(
  PART_ID            NUMBER  NOT NULL,
  PART_JORNADA       NUMBER  NOT NULL,
  PART_EQ_LOCAL      NUMBER  NOT NULL,
  PART_EQ_VISITANTE  NUMBER  NOT NULL,
  PART_FECHA         DATE    NOT NULL,
  PART_FINALIZADO_SN CHAR(1) DEFAULT 'N' NOT NULL
)
/
--
-- Clave Primaria PARTIDO
--
ALTER TABLE PARTIDO ADD CONSTRAINT PK_PARTIDO PRIMARY KEY (PART_ID)
/
--
-- Disparador tabla PARTIDO
--
CREATE OR REPLACE TRIGGER TRG_PARTIDO_INSERT 
BEFORE INSERT ON PARTIDO
FOR EACH ROW
  --
  BEGIN 
    --
    -- OBTIENE EL SIGUIENTE ID DE LA SECUENCIA SEQ_PARTIDO_ID
    -- 
    SELECT SEQ_PARTIDO_ID.NEXTVAL
      INTO :NEW.PART_ID
      FROM DUAL;
    --    
  END TRG_PARTIDO_INSERT;
/
--
-- Comentarios
--  
COMMENT ON COLUMN PARTIDO.PART_ID IS 'IDENTIFICADOR DEL PARTIDO'
/
COMMENT ON COLUMN PARTIDO.PART_JORNADA IS 'IDENTIFICADOR DE LA JORNADA'
/
COMMENT ON COLUMN PARTIDO.PART_EQ_LOCAL IS 'IDENTIFICADOR DEL EQUIPO LOCAL	'
/
COMMENT ON COLUMN PARTIDO.PART_EQ_VISITANTE IS 'IDENTIFICADOR DEL EQUIPO VISITANTE'
/
COMMENT ON COLUMN PARTIDO.PART_FECHA IS 'FECHA DEL PARTIDO'
/
COMMENT ON COLUMN PARTIDO.PART_FINALIZADO_SN IS 'S=FINALIZADO, N=NO HA FINALIZADO'
/
--
-- Tabla EQUIPO
--
CREATE TABLE EQUIPO(
  EQ_ID     NUMBER       NOT NULL,
  EQ_NOMBRE VARCHAR2(50)         ,
  EQ_PAIS   NUMBER       NOT NULL
)
/
--
-- Clave Primaria EQUIPO
--
ALTER TABLE EQUIPO ADD CONSTRAINT PK_EQUIPO PRIMARY KEY (EQ_ID)
/
--
ALTER TABLE EQUIPO ADD CONSTRAINT EQ_NOMBRE UNIQUE (EQ_NOMBRE)
/
--
-- Disparador tabla EQUIPO
--
CREATE OR REPLACE TRIGGER TRG_EQUIPO_INSERT 
BEFORE INSERT ON EQUIPO
FOR EACH ROW
  --
  BEGIN 
    --
    -- OBTIENE EL SIGUIENTE ID DE LA SECUENCIA SEQ_EQUIPO_ID
    -- 
    SELECT SEQ_EQUIPO_ID.NEXTVAL
      INTO :NEW.EQ_ID
      FROM DUAL;
    --       
  END TRG_EQUIPO_INSERT;
/
--
-- Comentarios
--
COMMENT ON COLUMN EQUIPO.EQ_ID IS 'IDENTIFICADOR DEL EQUIPO'
/
COMMENT ON COLUMN EQUIPO.EQ_NOMBRE IS 'NOMBRE DEL EQUIPO'
/
COMMENT ON COLUMN EQUIPO.EQ_PAIS IS 'IDENTIFICADOR DEL PAIS'
/
--
-- Tabla GOL
--
CREATE TABLE GOL(
  GOL_PARTIDO NUMBER      NOT NULL,
  GOL_NUMERO  NUMBER      NOT NULL,
  GOL_EQUIPO  NUMBER      NOT NULL,
  GOL_JUGADOR NUMBER      NOT NULL,
  GOL_TIEMPO  VARCHAR2(2) NOT NULL
)
/
--
-- Clave Primaria GOL
--
ALTER TABLE GOL ADD CONSTRAINT PK_GOL PRIMARY KEY (GOL_NUMERO,GOL_PARTIDO)
/
--
-- Disparador tabla GOL
--
CREATE OR REPLACE TRIGGER TRG_GOL_INSERT 
BEFORE INSERT ON GOL
FOR EACH ROW
  --
  BEGIN 
    --
    -- OBTIENE EL SIGUIENTE NUMERO DE GOL DEL PARTIDO
    -- 
    SELECT NVL(MAX(GOL_NUMERO), 0)+1 
      INTO :NEW.GOL_NUMERO
      FROM GOL
    WHERE GOL_PARTIDO = :NEW.GOL_PARTIDO;
    --     
  END TRG_GOL_INSERT;
/
--
-- Comentarios
--
COMMENT ON COLUMN GOL.GOL_PARTIDO IS 'IDENTIFICADOR DEL PARTIDO'
/
COMMENT ON COLUMN GOL.GOL_NUMERO IS 'NÚMERO DE ORDEN DEL GOL'
/
COMMENT ON COLUMN GOL.GOL_EQUIPO IS 'IDENTIFICADOR DEL EQUIPO'
/
COMMENT ON COLUMN GOL.GOL_JUGADOR IS 'IDENTIFICADOR DEL JUGADOR'
/
COMMENT ON COLUMN GOL.GOL_TIEMPO IS 'PERIODO: 1T=PRIMERA PARTE; 2T=SEGUNDA PARTE	'
/
--
-- Tabla JUGADOR
--
CREATE TABLE JUGADOR(
  JUG_ID     NUMBER       NOT NULL,
  JUG_NOMBRE VARCHAR2(50)         ,
  JUG_PAIS   NUMBER       NOT NULL
)
/
--
-- Clave Primaria JUGADOR
--
ALTER TABLE JUGADOR ADD CONSTRAINT PK_JUGADOR PRIMARY KEY (JUG_ID)
/
--
ALTER TABLE JUGADOR ADD CONSTRAINT JUG_NOMBRE UNIQUE (JUG_NOMBRE)
/
--
-- Disparador tabla JUGADOR
--
CREATE OR REPLACE TRIGGER TRG_JUGADOR_INSERT 
BEFORE INSERT ON JUGADOR
FOR EACH ROW
  --
  BEGIN 
    --
    -- OBTIENE EL SIGUIENTE ID DE LA SECUENCIA SEQ_JUGADOR_ID
    -- 
    SELECT SEQ_JUGADOR_ID.NEXTVAL
      INTO :NEW.JUG_ID
      FROM DUAL;
    --   
  END TRG_JUGADOR_INSERT;
/
--
-- Comentarios
--  
COMMENT ON COLUMN JUGADOR.JUG_ID IS 'IDENTIFICADOR DEL JUGADOR'
/
COMMENT ON COLUMN JUGADOR.JUG_NOMBRE IS 'NOMBRE DEL JUGADOR'
/
COMMENT ON COLUMN JUGADOR.JUG_PAIS IS 'IDENTIFICADOR DEL PAIS'
/
--
-- Tabla JUEGA
--
CREATE TABLE JUEGA(
  JUE_PARTIDO NUMBER NOT NULL,
  JUE_JUGADOR NUMBER NOT NULL
)
/
--
-- Clave Primaria JUEGA
--
ALTER TABLE JUEGA ADD CONSTRAINT PK_JUEGA PRIMARY KEY (JUE_PARTIDO,JUE_JUGADOR)
/
--
-- Tabla USUARIO
--
CREATE TABLE USUARIO(
  USU_ID               VARCHAR2(30) NOT NULL,
  USU_NOMBRE           VARCHAR2(30)         ,
  USU_FECHA_NACIMIENTO DATE         NOT NULL,
  USU_PAIS             INTEGER      NOT NULL
)
/
--
-- Clave Primaria USUARIO
--
ALTER TABLE USUARIO ADD CONSTRAINT PK_USUARIO PRIMARY KEY (USU_ID)
/
--
-- Tabla MODALIDAD
--
CREATE TABLE MODALIDAD(
  MOD_ID          NUMBER NOT NULL,
  MOD_DESCRIPCION VARCHAR2(50)   ,
  MOD_TIPO        NUMBER NOT NULL
)
/
--
-- Clave Primaria MODALIDAD
--
ALTER TABLE MODALIDAD ADD CONSTRAINT PK_MODALIDAD PRIMARY KEY (MOD_ID)
/
--
ALTER TABLE MODALIDAD ADD CONSTRAINT MOD_DESCRIPCION UNIQUE (MOD_DESCRIPCION)
/
-- Disparador tabla MODALIDAD

CREATE OR REPLACE TRIGGER TRG_MODALIDAD_INSERT 
BEFORE INSERT ON MODALIDAD
FOR EACH ROW
  --
  BEGIN 
    --
    -- OBTIENE EL SIGUIENTE ID DE LA SECUENCIA SEQ_MODALIDAD_ID
    -- 
    SELECT SEQ_MODALIDAD_ID.NEXTVAL
      INTO :NEW.MOD_ID
      FROM DUAL;
    --   
END TRG_MODALIDAD_INSERT;
/
--
-- Comentarios
--  
COMMENT ON COLUMN MODALIDAD.MOD_ID IS 'ID MODALIDAD'
/
COMMENT ON COLUMN MODALIDAD.MOD_DESCRIPCION IS 'DESCRIPCION DE LA MODALIDAD'
/
COMMENT ON COLUMN MODALIDAD.MOD_TIPO IS 'TIPO DE MODALIDAD'
/
--
-- Tabla TIPO_MODALIDAD
--
CREATE TABLE TIPO_MODALIDAD(
  TM_ID             NUMBER       NOT NULL,
  TM_DESCRIPCION    VARCHAR2(30) NOT NULL,
  TM_TIPO_RESULTADO VARCHAR2(30) NOT NULL
)
/
--
-- Clave Primaria TIPO_MODALIDAD
--
ALTER TABLE TIPO_MODALIDAD ADD CONSTRAINT PK_TIPO_MODALIDAD PRIMARY KEY (TM_ID)
/
--
ALTER TABLE TIPO_MODALIDAD ADD CONSTRAINT TM_TIPO_RESULTADO UNIQUE (TM_TIPO_RESULTADO)
/
--
ALTER TABLE TIPO_MODALIDAD ADD CONSTRAINT TM_DESCRIPCION UNIQUE (TM_DESCRIPCION)
/
--
-- Disparador tabla TIPO_MODALIDAD
--
CREATE OR REPLACE TRIGGER TRG_TIPO_MODALIDAD_INSERT 
BEFORE INSERT ON TIPO_MODALIDAD
FOR EACH ROW
  --
  BEGIN 
    --
    -- OBTIENE EL SIGUIENTE ID DE LA SECUENCIA SEQ_TIPO_MODALIDAD_ID
    -- 
    SELECT SEQ_TIPO_MODALIDAD_ID.NEXTVAL
      INTO :NEW.TM_ID
      FROM DUAL;
    --      
  END TRG_TIPO_MODALIDAD_INSERT;
/
--
-- Comentarios
--  
COMMENT ON COLUMN TIPO_MODALIDAD.TM_ID IS 'IDENTIFICADOR DE TIPO DE MODALIDAD'
/
COMMENT ON COLUMN TIPO_MODALIDAD.TM_DESCRIPCION IS 'DESCRIPCION DEL TIPO DE MODALIDAD'
/
COMMENT ON COLUMN TIPO_MODALIDAD.TM_TIPO_RESULTADO IS 'TIPO DE RESULTADO: Nº GOLES, JUGADOR, EQUIPO, RESULTADO,...'
/
--
-- Tabla APUESTA
--
CREATE TABLE APUESTA(
  APU_ID          NUMBER       NOT NULL,
  APU_PARTIDO     NUMBER       NOT NULL,
  APU_MODALIDAD   NUMBER       NOT NULL,
  APU_USUARIO     VARCHAR2(30) NOT NULL,
  APU_FECHA       DATE         NOT NULL,
  APU_IMPORTE     NUMBER(8,2)  DEFAULT 0 NOT NULL,
  APU_APUESTA     VARCHAR2(10) NOT NULL,
  APU_ACERTADA_SN CHAR(1)      DEFAULT 'N' NOT NULL
)
/
--
-- Clave Primaria APUESTA
--
ALTER TABLE APUESTA ADD CONSTRAINT PK_APUESTA PRIMARY KEY (APU_ID)
/
--
-- Disparador tabla APUESTA
--
CREATE OR REPLACE TRIGGER TRG_APUESTA_INSERT 
BEFORE INSERT ON APUESTA
FOR EACH ROW
  --
  BEGIN 
    --
    -- OBTIENE EL SIGUIENTE ID DE LA SECUENCIA SEQ_APUESTA_ID
    -- 
    SELECT SEQ_APUESTA_ID.NEXTVAL
      INTO :NEW.APU_ID
      FROM DUAL;
    --   
  END TRG_APUESTA_INSERT;
/
--
-- Comentarios
--  
COMMENT ON COLUMN APUESTA.APU_ID IS 'ID DE LA APUESTA'
/
COMMENT ON COLUMN APUESTA.APU_PARTIDO IS 'ID DEL PARTIDO'
/
COMMENT ON COLUMN APUESTA.APU_MODALIDAD IS 'modalidad de apuesta'
/
COMMENT ON COLUMN APUESTA.APU_FECHA IS 'FECHA DE LA APUESTA'
/
COMMENT ON COLUMN APUESTA.APU_IMPORTE IS 'IMPORTE DE LA APUESTA'
/
COMMENT ON COLUMN APUESTA.APU_APUESTA IS 'VALOR apostado. puede ser un equipo, un resultado, un jugador ó ''1X2'''
/
COMMENT ON COLUMN APUESTA.APU_ACERTADA_SN IS 'S= APUESTA GANADA; N=APUESTA PERDIDA'
/
--
-- Tabla PAIS
--
CREATE TABLE PAIS(
  PAIS_ID     NUMBER       NOT NULL,
  PAIS_NOMBRE VARCHAR2(50)
)
/
--
-- Clave Primaria PAIS
--
ALTER TABLE PAIS ADD CONSTRAINT PK_PAIS PRIMARY KEY (PAIS_ID)
/
--
ALTER TABLE PAIS ADD CONSTRAINT PAIS_NOMBRE UNIQUE (PAIS_NOMBRE)
/
--
-- Disparador tabla PAIS
--
CREATE OR REPLACE TRIGGER TRG_PAIS_INSERT
BEFORE INSERT ON PAIS
FOR EACH ROW
  --
  BEGIN 
    --
    -- OBTIENE EL SIGUIENTE ID DE LA SECUENCIA SEQ_PAIS_ID
    -- 
    SELECT SEQ_PAIS_ID.NEXTVAL
      INTO :NEW.PAIS_ID
      FROM DUAL;
    --    
  END TRG_PAIS_INSERT;
/
--
-- Comentarios
--  
COMMENT ON COLUMN PAIS.PAIS_ID IS 'IDENTIFICADOR DEL PAIS'
/
COMMENT ON COLUMN PAIS.PAIS_NOMBRE IS 'NOMBRE DEL PAIS'
/
--
-- Tabla JUG_EQ_TEMPORADA
--
CREATE TABLE JUG_EQ_TEMPORADA(
  JET_JUGADOR   NUMBER NOT NULL,
  JET_EQUIPO    NUMBER NOT NULL,
  JET_TEMPORADA NUMBER NOT NULL
)
/
--
-- Clave Primaria JUG_EQ_TEMPORADA
--
ALTER TABLE JUG_EQ_TEMPORADA ADD CONSTRAINT PK_JUG_EQ_TEMPORADA PRIMARY KEY (JET_JUGADOR,JET_EQUIPO,JET_TEMPORADA)
/
--
-- Comentarios
--  
COMMENT ON COLUMN JUG_EQ_TEMPORADA.JET_JUGADOR IS 'IDENTIFICADOR DEL JUGADOR'
/
COMMENT ON COLUMN JUG_EQ_TEMPORADA.JET_EQUIPO IS 'IDENTIFICADOR DEL EQUIPO'
/
COMMENT ON COLUMN JUG_EQ_TEMPORADA.JET_TEMPORADA IS 'IDENTIFICADOR DE LA TEMPORADA'
/
--
-- Tabla RESULTADO
--
CREATE TABLE RESULTADO(
  RES_PARTIDO   NUMBER       NOT NULL,
  RES_MODALIDAD NUMBER       NOT NULL,
  RES_RESULTADO VARCHAR2(10)
)
/
--
-- Clave Primaria RESULTADO
--
ALTER TABLE RESULTADO ADD CONSTRAINT PK_RESULTADO PRIMARY KEY (RES_PARTIDO,RES_MODALIDAD)
/

-- Comentarios
  
COMMENT ON COLUMN RESULTADO.RES_PARTIDO IS 'IDENTIFICADOR DEL PARTIDO'
/
COMMENT ON COLUMN RESULTADO.RES_MODALIDAD IS 'MODALIDAD DE APUESTA'
/
COMMENT ON COLUMN RESULTADO.RES_RESULTADO IS 'RESULTADO DE LA MODALIDAD EN EL PARTIDO'
/
--
-- Tabla LOG
--
CREATE TABLE LOG(
  LOG_ID            NUMBER        NOT NULL,
  LOG_PROCEDIMIENTO VARCHAR2(100) ,
  LOG_P_ENTRADA     VARCHAR2(1000),
  LOG_P_SALIDA      VARCHAR2(1000),
  LOG_RESULTADO     VARCHAR2(100) ,
  LOG_FECHA         DATE
)
/
--
-- Clave Primaria LOG
--
ALTER TABLE LOG ADD CONSTRAINT PK_LOG PRIMARY KEY (LOG_ID)
/
--
-- Disparador tabla LOG
--
CREATE OR REPLACE TRIGGER TRG_LOG_INSERT 
BEFORE INSERT ON LOG
FOR EACH ROW
  --
  BEGIN 
    --
    -- OBTIENE EL SIGUIENTE ID DE LA SECUENCIA SEQ_LOG_ID
    -- 
    SELECT SEQ_LOG_ID.NEXTVAL
      INTO :NEW.LOG_ID
      FROM DUAL;
    --   
  END TRG_LOG_INSERT;
/
--
-- Comentarios
--  
COMMENT ON COLUMN LOG.LOG_ID IS 'IDENTIFICADOR DEL REGISTRO LOG'
/
COMMENT ON COLUMN LOG.LOG_PROCEDIMIENTO IS 'NOMBRE DEL PROCEDIMIENTO EJECUTADO'
/
COMMENT ON COLUMN LOG.LOG_P_ENTRADA IS 'LISTA DE PARAMETROS DE ENTRADA CON LOS QUE SE EJECUTA EL PROCEDIMIENTO'
/
COMMENT ON COLUMN LOG.LOG_P_SALIDA IS 'LISTA DE PARAMETROS DE SALIDA Y VALORESTRAS LA EJECUCION DEL PROCEDIMIENTO'
/
COMMENT ON COLUMN LOG.LOG_RESULTADO IS 'RESULTADO OBTENIDO AL EJECUTAR EL PROCEDIMIENTO'
/
COMMENT ON COLUMN LOG.LOG_FECHA IS 'FECHA Y HORA EN QUE SE EJECUTA EL PROCEDIMIENTO'
/
/****
--
-- Trigger for sequence SEQ_TEMPORADA_ID for column TEMP_ID in table TEMPORADA ---------
--
CREATE OR REPLACE TRIGGER ts_TEMPORADA_SEQ_TEMPORADA_ID BEFORE INSERT
ON TEMPORADA FOR EACH ROW
BEGIN
	:new.TEMP_ID := SEQ_TEMPORADA_ID.nextval;
END;
/
CREATE OR REPLACE TRIGGER tsu_TEMPORADA_SEQ_TEMPORADA_ID AFTER UPDATE OF TEMP_ID
ON TEMPORADA FOR EACH ROW
BEGIN
	RAISE_APPLICATION_ERROR(-20010,'Cannot update column TEMP_ID in table TEMPORADA as it uses sequence.');
END;
/

-- Trigger for sequence SEQ_JORNADA_ID for column JOR_ID in table JORNADA ---------

CREATE OR REPLACE TRIGGER ts_JORNADA_SEQ_JORNADA_ID BEFORE INSERT
ON JORNADA FOR EACH ROW
BEGIN
	:new.JOR_ID := SEQ_JORNADA_ID.nextval;
END;
/
CREATE OR REPLACE TRIGGER tsu_JORNADA_SEQ_JORNADA_ID AFTER UPDATE OF JOR_ID
ON JORNADA FOR EACH ROW
BEGIN
	RAISE_APPLICATION_ERROR(-20010,'Cannot update column JOR_ID in table JORNADA as it uses sequence.');
END;
/

-- Trigger for sequence SEQ_PARTIDO_ID for column PART_ID in table PARTIDO ---------

CREATE OR REPLACE TRIGGER ts_PARTIDO_SEQ_PARTIDO_ID BEFORE INSERT
ON PARTIDO FOR EACH ROW
BEGIN
	:new.PART_ID := SEQ_PARTIDO_ID.nextval;
END;
/
CREATE OR REPLACE TRIGGER tsu_PARTIDO_SEQ_PARTIDO_ID AFTER UPDATE OF PART_ID
ON PARTIDO FOR EACH ROW
BEGIN
	RAISE_APPLICATION_ERROR(-20010,'Cannot update column PART_ID in table PARTIDO as it uses sequence.');
END;
/

-- Trigger for sequence SEQ_EQUIPO_ID for column EQ_ID in table EQUIPO ---------

CREATE OR REPLACE TRIGGER ts_EQUIPO_SEQ_EQUIPO_ID BEFORE INSERT
ON EQUIPO FOR EACH ROW
BEGIN
	:new.EQ_ID := SEQ_EQUIPO_ID.nextval;
END;
/
CREATE OR REPLACE TRIGGER tsu_EQUIPO_SEQ_EQUIPO_ID AFTER UPDATE OF EQ_ID
ON EQUIPO FOR EACH ROW
BEGIN
	RAISE_APPLICATION_ERROR(-20010,'Cannot update column EQ_ID in table EQUIPO as it uses sequence.');
END;
/

-- Trigger for sequence SEQ_JUGADOR_ID for column JUG_ID in table JUGADOR ---------

CREATE OR REPLACE TRIGGER ts_JUGADOR_SEQ_JUGADOR_ID BEFORE INSERT
ON JUGADOR FOR EACH ROW
BEGIN
	:new.JUG_ID := SEQ_JUGADOR_ID.nextval;
END;
/
CREATE OR REPLACE TRIGGER tsu_JUGADOR_SEQ_JUGADOR_ID AFTER UPDATE OF JUG_ID
ON JUGADOR FOR EACH ROW
BEGIN
	RAISE_APPLICATION_ERROR(-20010,'Cannot update column JUG_ID in table JUGADOR as it uses sequence.');
END;
/

-- Trigger for sequence SEQ_APUESTA_ID for column APU_ID in table APUESTA ---------

CREATE OR REPLACE TRIGGER ts_APUESTA_SEQ_APUESTA_ID BEFORE INSERT
ON APUESTA FOR EACH ROW
BEGIN
	:new.APU_ID := SEQ_APUESTA_ID.nextval;
END;
/
CREATE OR REPLACE TRIGGER tsu_APUESTA_SEQ_APUESTA_ID AFTER UPDATE OF APU_ID
ON APUESTA FOR EACH ROW
BEGIN
	RAISE_APPLICATION_ERROR(-20010,'Cannot update column APU_ID in table APUESTA as it uses sequence.');
END;
/

-- Trigger for sequence SEQ_PAIS_ID for column PAIS_ID in table PAIS ---------

CREATE OR REPLACE TRIGGER ts_PAIS_SEQ_PAIS_ID BEFORE INSERT
ON PAIS FOR EACH ROW
BEGIN
	:new.PAIS_ID := SEQ_PAIS_ID.nextval;
END;
/
CREATE OR REPLACE TRIGGER tsu_PAIS_SEQ_PAIS_ID AFTER UPDATE OF PAIS_ID
ON PAIS FOR EACH ROW
BEGIN
	RAISE_APPLICATION_ERROR(-20010,'Cannot update column PAIS_ID in table PAIS as it uses sequence.');
END;
/

-- Trigger for sequence SEQ_LOG_ID for column LOG_ID in table LOG ---------

CREATE OR REPLACE TRIGGER ts_LOG_SEQ_LOG_ID BEFORE INSERT
ON LOG FOR EACH ROW
BEGIN
	:new.LOG_ID := SEQ_LOG_ID.nextval;
END;
/
CREATE OR REPLACE TRIGGER tsu_LOG_SEQ_LOG_ID AFTER UPDATE OF LOG_ID
ON LOG FOR EACH ROW
BEGIN
	RAISE_APPLICATION_ERROR(-20010,'Cannot update column LOG_ID in table LOG as it uses sequence.');
END;
/
*/
--
--
-- Creación de RELACIONES ------------------------------------------------- 
--
ALTER TABLE JORNADA ADD CONSTRAINT R_TEMPORADA_JORNADA 
  FOREIGN KEY (JOR_TEMPORADA) 
  REFERENCES TEMPORADA (TEMP_ID)
/
ALTER TABLE JORNADA ADD CONSTRAINT R_COMPETICION_JORNADA 
  FOREIGN KEY (JOR_COMPETICION) 
  REFERENCES COMPETICION (COMP_ID)
/
--
ALTER TABLE JUG_EQ_TEMPORADA ADD CONSTRAINT R_JUG_TEMP 
  FOREIGN KEY (JET_JUGADOR) 
  REFERENCES JUGADOR (JUG_ID)
/
--
ALTER TABLE JUG_EQ_TEMPORADA ADD CONSTRAINT R_EQ_JUG_TEMP 
  FOREIGN KEY (JET_EQUIPO) 
  REFERENCES EQUIPO (EQ_ID)
/
--
ALTER TABLE JUG_EQ_TEMPORADA ADD CONSTRAINT R_JE_TEMPORADA 
  FOREIGN KEY (JET_TEMPORADA) 
  REFERENCES TEMPORADA (TEMP_ID)
/
--
ALTER TABLE PARTIDO ADD CONSTRAINT R_EQUIPO_PARTIDO 
  FOREIGN KEY (PART_EQ_LOCAL) 
  REFERENCES EQUIPO (EQ_ID)
/

ALTER TABLE JUGADOR ADD CONSTRAINT R_PAIS_JUGADOR 
  FOREIGN KEY (JUG_PAIS) 
  REFERENCES PAIS (PAIS_ID)
/

ALTER TABLE PARTIDO ADD CONSTRAINT es_visitante 
  FOREIGN KEY (PART_EQ_VISITANTE) 
  REFERENCES EQUIPO (EQ_ID)
/

ALTER TABLE GOL ADD CONSTRAINT R_EQUIPO_GOL 
  FOREIGN KEY (GOL_EQUIPO) 
  REFERENCES EQUIPO (EQ_ID)
/

ALTER TABLE GOL ADD CONSTRAINT R_JUG_GOL 
  FOREIGN KEY (GOL_JUGADOR) 
  REFERENCES JUGADOR (JUG_ID)
/

ALTER TABLE JUEGA ADD CONSTRAINT R_JUGADOR_JUEGA 
  FOREIGN KEY (JUE_JUGADOR) 
  REFERENCES JUGADOR (JUG_ID)
/

ALTER TABLE JUEGA ADD CONSTRAINT R_PARTIDO_JUEGA 
  FOREIGN KEY (JUE_PARTIDO) 
  REFERENCES PARTIDO (PART_ID)
/

ALTER TABLE EQUIPO ADD CONSTRAINT R_PAIS_EQUIPO 
  FOREIGN KEY (EQ_PAIS) 
  REFERENCES PAIS (PAIS_ID)
/

ALTER TABLE GOL ADD CONSTRAINT R_PARTIDO_GOL 
  FOREIGN KEY (GOL_PARTIDO) 
  REFERENCES PARTIDO (PART_ID)
/

ALTER TABLE MODALIDAD ADD CONSTRAINT T_TIPO_MODALIDAD 
  FOREIGN KEY (MOD_TIPO) 
  REFERENCES TIPO_MODALIDAD (TM_ID)
/

ALTER TABLE APUESTA ADD CONSTRAINT R_APU_MOD 
  FOREIGN KEY (APU_MODALIDAD) 
  REFERENCES MODALIDAD (MOD_ID)
/

ALTER TABLE APUESTA ADD CONSTRAINT R_APU_PART 
  FOREIGN KEY (APU_PARTIDO) 
  REFERENCES PARTIDO (PART_ID)
/

ALTER TABLE RESULTADO ADD CONSTRAINT R_PARTIDO_RESULTADO 
  FOREIGN KEY (RES_PARTIDO) 
  REFERENCES PARTIDO (PART_ID)
/

ALTER TABLE RESULTADO ADD CONSTRAINT R_MODALIDAD_RESULTADO 
  FOREIGN KEY (RES_MODALIDAD) 
  REFERENCES MODALIDAD (MOD_ID)
/



