﻿/*
Created: 25/03/2014
Modified: 26/03/2014
Project: Proyecto Fin de Carrera
Model: Modelo Lógico DW
Company: Universitat Oberta de Catalunya
Author: David Cuenca Aznar
Database: Oracle 11g Release 2
*/
--
-- Cambiamos al esquema USR_DW
--
ALTER SESSION SET CURRENT_SCHEMA = USR_DW;
--
-- ---------------------- Creación de SECUENCIAS ----------------------  --
CREATE SEQUENCE SEQ_USUARIO_DW_ID
 INCREMENT BY 1
 START WITH 1
 NOMAXVALUE
 NOMINVALUE
 CACHE 20
/
--
-- ---------------------- Creación de TABLAS ---------------------- --
--
-- Table D_USUARIO
--
CREATE TABLE D_USUARIO(
  USUARIO_DW_ID NUMBER       NOT NULL,
  USUARIO_ID    VARCHAR2(30) NOT NULL,
  EDAD          NUMBER       NOT NULL,
  TRAMO_EDAD    VARCHAR2(10) NOT NULL,
  NOMBRE        VARCHAR2(30) NOT NULL,
  PAIS          VARCHAR2(50) NOT NULL
)
/
--
-- Clave Primaria  D_USUARIO
--
ALTER TABLE D_USUARIO ADD CONSTRAINT PK_D_USUARIO PRIMARY KEY (USUARIO_DW_ID)
/
--
-- Table D_COMPETICION
--
CREATE TABLE D_COMPETICION(
  COMP_ID NUMBER        NOT NULL,
  NOMBRE  VARCHAR2(100) NOT NULL
)
/
--
-- Clave Primaria  D_COMPETICION
--
ALTER TABLE D_COMPETICION ADD CONSTRAINT PK_D_COMPETICION PRIMARY KEY (COMP_ID)
/
--
-- Table D_TEMPORADA
--
CREATE TABLE D_TEMPORADA(
  TEMP_ID NUMBER        NOT NULL,
  NOMBRE  VARCHAR2(100) NOT NULL
)
/
--
-- Clave Primaria  D_TEMPORADA
--
ALTER TABLE D_TEMPORADA ADD CONSTRAINT PK_D_TEMPORADA PRIMARY KEY (TEMP_ID)
/
--
-- Table D_EQUIPO
--
CREATE TABLE D_EQUIPO(
  EQ_ID Number NOT NULL,
  NOMBRE Varchar2(50 ) NOT NULL
)
/
--
-- Clave Primaria  D_EQUIPO
--
ALTER TABLE D_EQUIPO ADD CONSTRAINT PK_D_EQUIPO PRIMARY KEY (EQ_ID)
/
--
-- Table D_MODALIDAD
--
CREATE TABLE D_MODALIDAD(
  MOD_ID         NUMBER       NOT NULL,
  NOMBRE         VARCHAR2(50) NOT NULL,
  TIPO_MODALIDAD VARCHAR2(30) NOT NULL
)
/
--
-- Clave Primaria  D_MODALIDAD
--
ALTER TABLE D_MODALIDAD ADD CONSTRAINT PK_D_MODALIDAD PRIMARY KEY (MOD_ID)
/
--
-- Table D_JORNADA
--
CREATE TABLE D_JORNADA(
  JOR_ID NUMBER         NOT NULL,
  NOMBRE VARCHAR2(100 ) NOT NULL
)
/
--
-- Clave Primaria  D_JORNADA
--
ALTER TABLE D_JORNADA ADD CONSTRAINT PK_D_JORNADA PRIMARY KEY (JOR_ID)
/
--
-- Table D_JUGADOR
--
CREATE TABLE D_JUGADOR(
  JUG_ID NUMBER        NOT NULL,
  NOMBRE VARCHAR2(50 ) NOT NULL
)
/
--
-- Clave Primaria  D_JUGADOR
--
ALTER TABLE D_JUGADOR ADD CONSTRAINT PK_D_JUGADOR PRIMARY KEY (JUG_ID)
/
--
--
-- Table D_RESULTADO
--
CREATE TABLE D_RESULTADO(
  RES_ID      CHAR(1)       NOT NULL,
  DESCRIPCION VARCHAR2(100) NOT NULL
)
/
--
-- Clave Primaria  D_RESULTADO
--
ALTER TABLE D_RESULTADO ADD CONSTRAINT PK_D_RESULTADO PRIMARY KEY (RES_ID)
/
--
-- Table H_APUESTA
--
CREATE TABLE H_APUESTA(
  APU_ID      NUMBER       NOT NULL,
  USUARIO     NUMBER       NOT NULL,
  TEMPORADA   NUMBER       NOT NULL,
  COMPETICION NUMBER       NOT NULL,
  EQUIPO      NUMBER       NOT NULL,
  MODALIDAD   NUMBER       NOT NULL,
  JORNADA     NUMBER       NOT NULL,
  JUGADOR     NUMBER       NOT NULL,
  ACERTADA_SN CHAR(1 )     NOT NULL,
  IMPORTE     NUMBER(10,2) NOT NULL
)
/
--
-- Clave Primaria  H_APUESTA
--
ALTER TABLE H_APUESTA ADD CONSTRAINT PK_H_APUESTA PRIMARY KEY (APU_ID,USUARIO,JORNADA,JUGADOR,TEMPORADA,MODALIDAD,COMPETICION,EQUIPO)
/
--
-- Table and Columns comments section
--  
COMMENT ON COLUMN H_APUESTA.ACERTADA_SN IS 'S=ACIERTO; N=FALLO'
/
--
-- Trigger for sequence SEQ_USUARIO_DW_ID for column USUARIO_DW_ID in table D_USUARIO ---------
--
CREATE OR REPLACE TRIGGER ts_D_USUARIO_SEQ_USUARIO_DW_ID BEFORE INSERT
ON D_USUARIO FOR EACH ROW
BEGIN
	:new.USUARIO_DW_ID := SEQ_USUARIO_DW_ID.nextval;
END;
/
CREATE OR REPLACE TRIGGER tsu_D_USUARIO_SEQ_USUARIO_DW_0 AFTER UPDATE OF USUARIO_DW_ID
ON D_USUARIO FOR EACH ROW
BEGIN
	RAISE_APPLICATION_ERROR(-20010,'Cannot update column USUARIO_DW_ID in table D_USUARIO as it uses sequence.');
END;
/
--
-- Relaciones ------------------------------------------------- 
--
ALTER TABLE H_APUESTA ADD CONSTRAINT R_USU_APU FOREIGN KEY (USUARIO) REFERENCES D_USUARIO (USUARIO_DW_ID)
/

ALTER TABLE H_APUESTA ADD CONSTRAINT R_JOR_AP FOREIGN KEY (JORNADA) REFERENCES D_JORNADA (JOR_ID)
/

ALTER TABLE H_APUESTA ADD CONSTRAINT R_JUG_APU FOREIGN KEY (JUGADOR) REFERENCES D_JUGADOR (JUG_ID)
/

ALTER TABLE H_APUESTA ADD CONSTRAINT R_TEMP_APU FOREIGN KEY (TEMPORADA) REFERENCES D_TEMPORADA (TEMP_ID)
/

ALTER TABLE H_APUESTA ADD CONSTRAINT R_MOD_APU FOREIGN KEY (MODALIDAD) REFERENCES D_MODALIDAD (MOD_ID)
/

ALTER TABLE H_APUESTA ADD CONSTRAINT R_COMP_APU FOREIGN KEY (COMPETICION) REFERENCES D_COMPETICION (COMP_ID)
/

ALTER TABLE H_APUESTA ADD CONSTRAINT R_EQ_APU FOREIGN KEY (EQUIPO) REFERENCES D_EQUIPO (EQ_ID)
/

ALTER TABLE H_APUESTA ADD CONSTRAINT R_RES_APU FOREIGN KEY (ACERTADA_SN) REFERENCES D_RESULTADO (RES_ID)
/


