CREATE OR REPLACE PACKAGE USR_OP.G_LOG AS
  --
  -- Gestin del LOG
  --
  PROCEDURE ALTA(PROCEDIMIENTO IN USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE,
                 P_ENTRADA     IN USR_OP.LOG.LOG_P_ENTRADA%TYPE    ,
                 P_SALIDA      IN USR_OP.LOG.LOG_P_SALIDA%TYPE     ,
                 RESPUESTA     IN USR_OP.LOG.LOG_RESULTADO%TYPE    ,
                 FECHA         IN USR_OP.LOG.LOG_FECHA%TYPE        ,
                 RESULTADO     OUT NUMBER                          );
  --
  PROCEDURE CONSULTA(ID            IN  USR_OP.LOG.LOG_ID%TYPE           ,
                    PROCEDIMIENTO IN  USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE,
                    FECHA         IN  USR_OP.LOG.LOG_FECHA%TYPE        ,
                    RESPUESTA     OUT USR_OP.LOG.LOG_RESULTADO%TYPE    ,
                    RS            OUT SYS_REFCURSOR                    );
  --
END G_LOG;  
--
--
-- Gestin del LOG
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_LOG AS
  --
  PROCEDURE ALTA(PROCEDIMIENTO IN USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE,
                 P_ENTRADA     IN USR_OP.LOG.LOG_P_ENTRADA%TYPE    ,
                 P_SALIDA      IN USR_OP.LOG.LOG_P_SALIDA%TYPE     ,
                 RESPUESTA     IN USR_OP.LOG.LOG_RESULTADO%TYPE    ,
                 FECHA         IN USR_OP.LOG.LOG_FECHA%TYPE        ,
                 RESULTADO     OUT NUMBER                          ) IS
    --
    -- HACEMOS QUE EL COMMIT DE ESTA FUNCION SOLO AFECTE A ESTA FUNCIN
    --
    PRAGMA AUTONOMOUS_TRANSACTION;
    --
  BEGIN
    --
    RESULTADO := 0;
    --
    INSERT 
      INTO USR_OP.LOG(LOG_PROCEDIMIENTO,
               LOG_P_ENTRADA    ,
               LOG_P_SALIDA     ,
               LOG_RESULTADO    ,
               LOG_FECHA        )
        VALUES(PROCEDIMIENTO,
               P_ENTRADA    ,
               P_SALIDA     ,
               RESPUESTA    ,
               FECHA        );
    --
    --
    COMMIT;                                
    --
  EXCEPTION 
  WHEN OTHERS THEN
    --
    RESULTADO := -1;   
    --
  END ALTA;
  --                
  --
  PROCEDURE CONSULTA(ID            IN  USR_OP.LOG.LOG_ID%TYPE           ,
                    PROCEDIMIENTO IN  USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE,
                    FECHA         IN  USR_OP.LOG.LOG_FECHA%TYPE        ,
                    RESPUESTA     OUT USR_OP.LOG.LOG_RESULTADO%TYPE    ,
                    RS            OUT SYS_REFCURSOR                    ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE;
    --
    R_LOG             NUMBER;
    --RS                SYS_REFCURSOR;  
    --    
    --               
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'LOG.CONSULTA';
      P_ENTRADA_LOG     := 'ID=' || ID || ', PROCEDIMIENTO=' || PROCEDIMIENTO || ', FECHA =' || FECHA;      
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF ID IS NOT NULL THEN
        --
        -- SI SE INDICA UN ID BUSCAMOS ESE ID
        --
        OPEN RS FOR
          SELECT LOG_ID           ,
                 LOG_PROCEDIMIENTO,
                 LOG_P_ENTRADA    ,
                 LOG_P_SALIDA     ,
                 LOG_RESULTADO    ,
                 LOG_FECHA
            FROM LOG
           WHERE LOG_ID = ID;
        --
      ELSE 
        --
        -- ID ES NULO
        --
        IF (PROCEDIMIENTO IS NOT NULL AND
            FECHA         IS NOT NULL    ) THEN
          --
          -- FILTRAMOS POR PROCEDIMIENTO Y POR FECHA
          --                 
          OPEN RS FOR
            SELECT LOG_ID           ,
                   LOG_PROCEDIMIENTO,
                   LOG_P_ENTRADA    ,
                   LOG_P_SALIDA     ,
                   LOG_RESULTADO    ,
                   LOG_FECHA
              FROM LOG
             WHERE LOG_PROCEDIMIENTO = PROCEDIMIENTO AND
                   LOG_FECHA         = FECHA;
          --
        ELSE
          --
          -- SI SOLAMENTE SE INDICA EL PROCEDIMIENTO
          --
          IF PROCEDIMIENTO IS NOT NULL THEN  
            --
            OPEN RS FOR
              SELECT LOG_ID           ,
                     LOG_PROCEDIMIENTO,
                     LOG_P_ENTRADA    ,
                     LOG_P_SALIDA     ,
                     LOG_RESULTADO    ,
                     LOG_FECHA
                FROM LOG
               WHERE LOG_PROCEDIMIENTO = PROCEDIMIENTO;
            --
          ELSE
            --
            -- SI SOLAMENTE SE INDICA LA FECHA
            --
            IF FECHA IS NOT NULL THEN
              --
              OPEN RS FOR
                SELECT LOG_ID           ,
                       LOG_PROCEDIMIENTO,
                       LOG_P_ENTRADA    ,
                       LOG_P_SALIDA     ,
                       LOG_RESULTADO    ,
                       LOG_FECHA
                  FROM LOG
                 WHERE LOG_FECHA = FECHA; 

              --
            ELSE
              --
              -- SI NO SE INDICA NINGUN PARAMETRO SE DEVUELVEN TODOS LOS REGISTROS
              --   
              OPEN RS FOR
                SELECT LOG_ID           ,
                       LOG_PROCEDIMIENTO,
                       LOG_P_ENTRADA    ,
                       LOG_P_SALIDA     ,
                       LOG_RESULTADO    ,
                       LOG_FECHA
                  FROM LOG;
              --      
            END IF;  
            --     
        END IF;       
        --
      END IF;  
      --
    END IF;
    --
    IF RS%FOUND IS NULL THEN 
      --
      RESPUESTA := 'ERROR. NO SE HAN ENCONTRADO DATOS';
      --
    END IF;
    --
    USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                      P_ENTRADA_LOG,
                      NULL         ,
                      RESPUESTA    ,
                      FECHA_LOG    ,
                      R_LOG);
    --
  EXCEPTION
    --
    WHEN NO_DATA_FOUND THEN
      --
      RESPUESTA := 'ERROR. NO SE HAN ENCONTRADO DATOS';
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO,
                        P_ENTRADA_LOG,
                        NULL         ,
                        RESPUESTA    ,
                        FECHA_LOG    ,
                        R_LOG);   
      --
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO,
                        P_ENTRADA_LOG,
                        NULL         ,
                        RESPUESTA    ,
                        FECHA_LOG    ,
                        R_LOG        );   
      --
      --RETURN(NULL);
      --              
  END CONSULTA;
  --
END G_LOG;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_TEMPORADA AS
  --
  -- /* Gestin de Temporadas */
  --
  PROCEDURE ALTA(DESCRIPCION IN  TEMPORADA.TEMP_DESCRIPCION%TYPE,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO   OUT NUMBER                         );
  --
  PROCEDURE BAJA(ID          IN  TEMPORADA.TEMP_ID%TYPE         ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO   OUT NUMBER                         );
  --
  PROCEDURE MODIFICAR(ID          IN  TEMPORADA.TEMP_ID%TYPE         ,
                      DESCRIPCION IN  TEMPORADA.TEMP_DESCRIPCION%TYPE,
                      RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                      RESULTADO   OUT NUMBER                         );
  --
  PROCEDURE CONSULTA(ID          IN  TEMPORADA.TEMP_ID%TYPE         ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                     RS          OUT SYS_REFCURSOR                  );
  --                      
END G_TEMPORADA;  
--
--
--
--
-- GESTION DE TEMPORADAS
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_TEMPORADA AS
  --
  --
  -- INSERTA UNA TEMPORADA EN EL SISTEMA
  --  
  PROCEDURE ALTA(DESCRIPCION IN   TEMPORADA.TEMP_DESCRIPCION%TYPE,
                 RESPUESTA   OUT  USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO   OUT  NUMBER                         ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_TEMPORADA.ALTA';
      P_ENTRADA_LOG     := 'DESCRIPCION=' || DESCRIPCION;
      --
      RESULTADO := 0;
      --
      INSERT INTO TEMPORADA(TEMP_DESCRIPCION)
        VALUES (DESCRIPCION);
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. TEMPORADA CREADA';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. YA HAY UNA TEMPORADA CON LA MISMA DESCRIPCION';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UNA TEMPORADA DEL SISTEMA
    --
  PROCEDURE BAJA(ID          IN  TEMPORADA.TEMP_ID%TYPE         ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO   OUT NUMBER                         ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_TEMPORADA.BAJA';
      P_ENTRADA_LOG     := 'ID=' || ID       ;
      --
      RESULTADO := 0;                     
      --
      DELETE FROM TEMPORADA
        WHERE TEMP_ID = ID;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. TEMPORADA ELIMINADA';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      --                                  
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END BAJA;
    --
    --
    -- MODIFICA UNA TEMPORADA
    --
  PROCEDURE MODIFICAR(ID          IN  TEMPORADA.TEMP_ID%TYPE         ,
                      DESCRIPCION IN  TEMPORADA.TEMP_DESCRIPCION%TYPE,
                      RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                      RESULTADO   OUT NUMBER                         ) IS                        
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_TEMPORADA.MODIFICAR';
      P_ENTRADA_LOG     := 'ID=' || ID || ', DESCRIPCION=' || DESCRIPCION ;
      --
      RESULTADO := 0;                     
      --
      UPDATE TEMPORADA
         SET TEMP_DESCRIPCION = DESCRIPCION
       WHERE TEMP_ID = ID;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. TEMPORADA MODIFICADA';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      -- 
      WHEN DUP_VAL_ON_INDEX THEN
        --
        RESPUESTA := 'ERROR. YA HAY UNA TEMPORADA CON LA MISMA DESCRIPCION';
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
        --              
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE TEMPORADAS
  --
  PROCEDURE CONSULTA(ID          IN  TEMPORADA.TEMP_ID%TYPE         ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                     RS          OUT SYS_REFCURSOR                  ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE;
    --
    R_LOG             NUMBER;
    --
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'TEMPORADA.CONSULTA';
      P_ENTRADA_LOG     := 'ID=' || ID;      
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF ID IS NOT NULL THEN
         --
         OPEN RS FOR
           SELECT TEMP_ID         ,
                  TEMP_DESCRIPCION
             FROM TEMPORADA
            WHERE TEMP_ID = ID;     
         --   
      ELSE
        --
         OPEN RS FOR
           SELECT TEMP_ID         ,
                  TEMP_DESCRIPCION
             FROM TEMPORADA;        
        --
      END IF;  
      --     
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG        );
    --
  EXCEPTION
  WHEN OTHERS THEN
    --
    RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
    --
    USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                      P_ENTRADA_LOG,
                      NULL         ,
                      RESPUESTA    ,
                      FECHA_LOG    ,
                      R_LOG        );      
    --              
  END CONSULTA;
  --                      
END G_TEMPORADA;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_COMPETICION AS
  --
  -- /* Gestin de COMPETICIONES */
  --
  PROCEDURE ALTA(DESCRIPCION IN  COMPETICION.COMP_DESCRIPCION%TYPE,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE    ,
                 RESULTADO   OUT NUMBER                           );
  --
  PROCEDURE BAJA(ID          IN  COMPETICION.COMP_ID%TYPE       ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       );
  --
  PROCEDURE MODIFICAR(ID          IN  COMPETICION.COMP_ID%TYPE         ,
                      DESCRIPCION IN  COMPETICION.COMP_DESCRIPCION%TYPE,
                      RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                      RESULTADO   OUT NUMBER                         );
  --
  PROCEDURE CONSULTA(ID          IN  COMPETICION.COMP_ID%TYPE         ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                     RS          OUT SYS_REFCURSOR                  );
  --                      
END G_COMPETICION;  
--
--
-- GESTION DE COMPETICIONES
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_COMPETICION AS
  --
  --
  -- INSERTA UNA COMPETICION EN EL SISTEMA
  --  
  PROCEDURE ALTA(DESCRIPCION IN   COMPETICION.COMP_DESCRIPCION%TYPE,
                 RESPUESTA   OUT  USR_OP.LOG.LOG_RESULTADO%TYPE    ,
                 RESULTADO   OUT  NUMBER                           ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_COMPETICION.ALTA';
      P_ENTRADA_LOG     := 'DESCRIPCION=' || DESCRIPCION;
      --
      RESULTADO := 0;
      --
      INSERT INTO COMPETICION(COMP_DESCRIPCION)
        VALUES (DESCRIPCION);
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. COMPETICION CREADA';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. YA HAY UNA COMPETICION CON LA MISMA DESCRIPCION';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UNA COMPETICION DEL SISTEMA
    --
  PROCEDURE BAJA(ID          IN  COMPETICION.COMP_ID%TYPE         ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO   OUT NUMBER                         ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_COMPETICIONA.BAJA';
      P_ENTRADA_LOG     := 'ID=' || ID       ;
      --
      RESULTADO := 0;                     
      --
      DELETE FROM COMPETICION
        WHERE COMP_ID = ID;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. COMPETICION ELIMINADA';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      --                                  
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );       
      --
    END BAJA;
    --
    --
    -- MODIFICA UNA COMPETICION
    --
  PROCEDURE MODIFICAR(ID          IN  COMPETICION.COMP_ID%TYPE         ,
                      DESCRIPCION IN  COMPETICION.COMP_DESCRIPCION%TYPE,
                      RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                      RESULTADO   OUT NUMBER                         ) IS                        
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_COMPETICION.MODIFICAR';
      P_ENTRADA_LOG     := 'ID=' || ID || ', DESCRIPCION=' || DESCRIPCION ;
      --
      RESULTADO := 0;                     
      --
      UPDATE COMPETICION
         SET COMP_DESCRIPCION = DESCRIPCION
       WHERE COMP_ID = ID;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. COMPETICION MODIFICADA';
        --
      END IF;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      -- 
      WHEN DUP_VAL_ON_INDEX THEN
        --
        RESPUESTA := 'ERROR. YA HAY UNA COMPETICION CON LA MISMA DESCRIPCION';
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
        --              
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE COMPETICION
  --
  PROCEDURE CONSULTA(ID          IN  COMPETICION.COMP_ID%TYPE       ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                     RS          OUT SYS_REFCURSOR                  ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE;
    --
    R_LOG             NUMBER;
    --
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_COMPETICION.CONSULTA';
      P_ENTRADA_LOG     := 'ID=' || ID;      
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF ID IS NOT NULL THEN
         --
         OPEN RS FOR
           SELECT COMP_ID         ,
                  COMP_DESCRIPCION
             FROM COMPETICION
            WHERE COMP_ID = ID;     
         --   
      ELSE
        --
         OPEN RS FOR
           SELECT COMP_ID         ,
                  COMP_DESCRIPCION
             FROM COMPETICION;        
        --
      END IF;  
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG        );
    --
  EXCEPTION
  WHEN OTHERS THEN
    --
    RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
    --
    USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                      P_ENTRADA_LOG,
                      NULL         ,
                      RESPUESTA    ,
                      FECHA_LOG    ,
                      R_LOG        );   
    
    --              
  END CONSULTA;
  --                      
END G_COMPETICION;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_PAIS AS
  --
  -- /* Gestin de PAISES */
  --
  PROCEDURE ALTA(NOMBRE    IN  PAIS.PAIS_NOMBRE%TYPE,
                 RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO OUT NUMBER                         );
  --
  PROCEDURE BAJA(ID          IN  PAIS.PAIS_ID%TYPE         ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO   OUT NUMBER                         );
  --
  PROCEDURE MODIFICAR(ID         IN  PAIS.PAIS_ID%TYPE         ,
                      NOMBRE     IN  PAIS.PAIS_NOMBRE%TYPE,
                      RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                      RESULTADO  OUT NUMBER                         );
  --
  PROCEDURE CONSULTA(ID          IN  PAIS.PAIS_ID%TYPE         ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                     RS          OUT SYS_REFCURSOR                  );
  --                      
END G_PAIS;  
--
--
-- GESTION DE PAISES
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_PAIS AS
  --
  --
  -- INSERTA UN PAIS EN EL SISTEMA
  --  
  PROCEDURE ALTA(NOMBRE    IN   PAIS.PAIS_NOMBRE%TYPE,
                 RESPUESTA OUT  USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO OUT  NUMBER                         ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_PAIS.ALTA';
      P_ENTRADA_LOG     := 'NOMBRE=' || NOMBRE;
      --
      RESULTADO := 0;
      --
      INSERT INTO PAIS(PAIS_NOMBRE)
        VALUES (NOMBRE);
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. PAIS CREADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. YA HAY UN PAIS CON EL MISMO NOMBRE';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UN PAIS DEL SISTEMA
    --
  PROCEDURE BAJA(ID          IN  PAIS.PAIS_ID%TYPE              ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO   OUT NUMBER                         ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_PAIS.BAJA';
      P_ENTRADA_LOG     := 'ID=' || ID       ;
      --
      RESULTADO := 0;                     
      --
      DELETE FROM PAIS
       WHERE PAIS_ID = ID;
       
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. PAIS ELIMINADO';
        --
      END IF;   
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      --                                  
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END BAJA;
    --
    --
    -- MODIFICA UN PAIS
    --
  PROCEDURE MODIFICAR(ID        IN  PAIS.PAIS_ID%TYPE            ,
                      NOMBRE    IN  PAIS.PAIS_NOMBRE%TYPE        ,
                      RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                      RESULTADO OUT NUMBER                       ) IS                        
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_PAIS.MODIFICAR';
      P_ENTRADA_LOG     := 'ID=' || ID || ', NOMBRE=' || NOMBRE ;
      --
      RESULTADO := 0;                     
      --
      UPDATE PAIS
         SET PAIS_NOMBRE = NOMBRE
       WHERE PAIS_ID = ID;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. PAIS MODIFICADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      -- 
      WHEN DUP_VAL_ON_INDEX THEN
        --
        RESPUESTA := 'ERROR. YA HAY UN PAIS CON EL MISMO NOMBRE';
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
        --              
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE PAISES
  --
  PROCEDURE CONSULTA(ID          IN  PAIS.PAIS_ID%TYPE            ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE;
    --
    R_LOG             NUMBER;
    --
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_PAIS.CONSULTA';
      P_ENTRADA_LOG     := 'ID=' || ID;      
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF ID IS NOT NULL THEN
         --
         OPEN RS FOR
           SELECT PAIS_ID    ,
                  PAIS_NOMBRE
             FROM PAIS
            WHERE PAIS_ID = ID;     
         --   
      ELSE
        --
         OPEN RS FOR
           SELECT PAIS_ID    ,
                  PAIS_NOMBRE
             FROM PAIS;        
        --
      END IF;  
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );   
      --              
  END CONSULTA;
  --                      
END G_PAIS;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_EQUIPO AS
  --
  -- /* Gestin de EQUIPOS */
  --
  PROCEDURE ALTA(NOMBRE    IN  EQUIPO.EQ_NOMBRE%TYPE        ,
                 PAIS      IN  EQUIPO.EQ_PAIS%TYPE          ,
                 RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO OUT NUMBER                       );
  --
  PROCEDURE BAJA(ID          IN  EQUIPO.EQ_ID%TYPE            ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       );
  --
  PROCEDURE MODIFICAR(ID         IN  EQUIPO.EQ_ID%TYPE            ,
                      NOMBRE     IN  EQUIPO.EQ_NOMBRE%TYPE        ,
                      PAIS       IN  EQUIPO.EQ_PAIS%TYPE          ,
                      RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                      RESULTADO  OUT NUMBER                       );
  --
  PROCEDURE CONSULTA(ID          IN  EQUIPO.EQ_ID%TYPE            ,
                     PAIS        IN  EQUIPO.EQ_PAIS%TYPE          , 
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                );
  --                      
END G_EQUIPO;  
--
--
-- GESTION DE EQUIPOS
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_EQUIPO AS
  --
  --
  -- INSERTA UN EQUIPO EN EL SISTEMA
  --  
  PROCEDURE ALTA(NOMBRE    IN   EQUIPO.EQ_NOMBRE%TYPE        ,
                 PAIS      IN   EQUIPO.EQ_PAIS%TYPE          ,
                 RESPUESTA OUT  USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO OUT  NUMBER                       ) IS
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_EQUIPO.ALTA';
      P_ENTRADA_LOG     := 'NOMBRE=' || NOMBRE || ', PAIS=' || PAIS;
      --
      RESULTADO := 0;
      --
      IF PAIS IS NULL THEN
        --
        RESULTADO := -1;
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      INSERT INTO EQUIPO(EQ_NOMBRE,
                         EQ_PAIS  )
        VALUES (NOMBRE,
                PAIS  );
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. EQUIPO CREADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      RESPUESTA := 'ERROR. SE DEBE INDICAR EL PAIS';
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
      
      --
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. YA HAY UN EQUIPO CON EL MISMO NOMBRE';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UN EQUIPO DEL SISTEMA
    --
  PROCEDURE BAJA(ID          IN  EQUIPO.EQ_ID%TYPE              ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO   OUT NUMBER                         ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_EQUIPO.BAJA';
      P_ENTRADA_LOG     := 'ID=' || ID    ;
      --
      RESULTADO := 0;                     
      --
      DELETE FROM EQUIPO
       WHERE EQ_ID = ID; 
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. EQUIPO ELIMINADO';
        --
      END IF;   
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      --                                  
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END BAJA;
    --
    --
    -- MODIFICA UN EQUIPO
    --
  PROCEDURE MODIFICAR(ID        IN  EQUIPO.EQ_ID%TYPE            ,
                      NOMBRE    IN  EQUIPO.EQ_NOMBRE%TYPE        ,
                      PAIS      IN  EQUIPO.EQ_PAIS%TYPE          ,
                      RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                      RESULTADO OUT NUMBER                       ) IS                        
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_EQUIPO.MODIFICAR';
      P_ENTRADA_LOG     := 'ID=' || ID || ', NOMBRE=' || NOMBRE || 'PAIS=' || PAIS;
      --
      RESULTADO := 0;                     
      --
      UPDATE EQUIPO
         SET EQ_NOMBRE = NOMBRE,
             EQ_PAIS   = PAIS
       WHERE EQ_ID = ID;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. EQUIPO MODIFICADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      -- 
      WHEN DUP_VAL_ON_INDEX THEN
        --
        RESPUESTA := 'ERROR. YA HAY UN EQUIPO CON EL MISMO NOMBRE';
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
        --              
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE EQUIPOS
  --
  PROCEDURE CONSULTA(ID          IN  EQUIPO.EQ_ID%TYPE            ,
                     PAIS        IN  EQUIPO.EQ_PAIS%TYPE          , 
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE;
    --
    R_LOG             NUMBER;
    --
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_EQUIPO.CONSULTA';
      P_ENTRADA_LOG     := 'ID=' || ID || 'PAIS=' || PAIS;      
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF ID IS NOT NULL THEN
         --
         -- BUSCAMOS EL EQUIPO POR ID
         --
         OPEN RS FOR
           SELECT EQ_ID    ,
                  EQ_NOMBRE,
                  EQ_PAIS
             FROM EQUIPO
            WHERE EQ_ID = ID;     
         --   
      ELSE
        --
        IF PAIS IS NOT NULL THEN
          --
          -- BUSCAMOS POR PAIS
          --
          OPEN RS FOR
            SELECT EQ_ID    ,
                   EQ_NOMBRE,
                   EQ_PAIS
              FROM EQUIPO
             WHERE EQ_PAIS = PAIS;        
          --
        ELSE
          --
          -- BUSCAMOS TODOS LOS EQUIPOS
          OPEN RS FOR
            SELECT EQ_ID    ,
                   EQ_NOMBRE,
                   EQ_PAIS
              FROM EQUIPO;          
          --
        END IF;       
        --
      END IF;  
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );   
      --              
  END CONSULTA;
  --                      
END G_EQUIPO;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_JUGADOR AS
  --
  -- /* Gestin de JUGADORES */
  --
  PROCEDURE ALTA(NOMBRE    IN  JUGADOR.JUG_NOMBRE%TYPE        ,
                 PAIS      IN  JUGADOR.JUG_PAIS%TYPE          ,
                 RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO OUT NUMBER                       );
  --
  PROCEDURE BAJA(ID          IN  JUGADOR.JUG_ID%TYPE            ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       );
  --
  PROCEDURE MODIFICAR(ID         IN  JUGADOR.JUG_ID%TYPE            ,
                      NOMBRE     IN  JUGADOR.JUG_NOMBRE%TYPE        ,
                      PAIS       IN  JUGADOR.JUG_PAIS%TYPE          ,
                      RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                      RESULTADO  OUT NUMBER                       );
  --
  PROCEDURE CONSULTA(ID          IN  JUGADOR.JUG_ID%TYPE            ,
                     PAIS        IN  JUGADOR.JUG_PAIS%TYPE          , 
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                );
  --                      
END G_JUGADOR;  
--
--
-- GESTION DE JUGADORES
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_JUGADOR AS
  --
  --
  -- INSERTA UN JUGADOR EN EL SISTEMA
  --  
  PROCEDURE ALTA(NOMBRE    IN  JUGADOR.JUG_NOMBRE%TYPE       ,
                 PAIS      IN  JUGADOR.JUG_PAIS%TYPE         ,
                 RESPUESTA OUT  USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO OUT  NUMBER                       ) IS
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JUGADOR.ALTA';
      P_ENTRADA_LOG     := 'NOMBRE=' || NOMBRE || ', PAIS=' || PAIS;
      --
      RESULTADO := 0;
      --
      IF PAIS IS NULL THEN
        --
        RESULTADO := -1;
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      INSERT INTO JUGADOR(JUG_NOMBRE,
                          JUG_PAIS  )
        VALUES (NOMBRE,
                PAIS  );
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. JUGADOR CREADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      RESPUESTA := 'ERROR. SE DEBE INDICAR EL PAIS';
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. YA HAY UN JUGADOR CON EL MISMO NOMBRE';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UN JUGADOR DEL SISTEMA
    --
  PROCEDURE BAJA(ID          IN  JUGADOR.JUG_ID%TYPE              ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO   OUT NUMBER                         ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JUGADOR.BAJA';
      P_ENTRADA_LOG     := 'ID=' || ID    ;
      --
      RESULTADO := 0;                     
      --
      DELETE FROM JUGADOR
       WHERE JUG_ID = ID; 
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. JUGADOR ELIMINADO';
        --
      END IF;   
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      --                                  
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END BAJA;
    --
    --
    -- MODIFICA UN JUGADOR
    --
  PROCEDURE MODIFICAR(ID        IN  JUGADOR.JUG_ID%TYPE            ,
                      NOMBRE    IN  JUGADOR.JUG_NOMBRE%TYPE        ,
                      PAIS      IN  JUGADOR.JUG_PAIS%TYPE          ,
                      RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                      RESULTADO OUT NUMBER                       ) IS                        
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JUGADOR.MODIFICAR';
      P_ENTRADA_LOG     := 'ID=' || ID || ', NOMBRE=' || NOMBRE || 'PAIS=' || PAIS;
      --
      RESULTADO := 0;                     
      --
      UPDATE JUGADOR
         SET JUG_NOMBRE = NOMBRE,
             JUG_PAIS   = PAIS
       WHERE JUG_ID = ID;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. JUGADOR MODIFICADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      -- 
      WHEN DUP_VAL_ON_INDEX THEN
        --
        RESPUESTA := 'ERROR. YA HAY UN JUGADOR CON EL MISMO NOMBRE';
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
        --              
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE JUGADORES
  --
  PROCEDURE CONSULTA(ID          IN  JUGADOR.JUG_ID%TYPE          ,
                     PAIS        IN  JUGADOR.JUG_PAIS%TYPE        , 
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE    ;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE        ;
    --
    R_LOG             NUMBER;
    --
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JUGADOR.CONSULTA';
      P_ENTRADA_LOG     := 'ID=' || ID || 'PAIS=' || PAIS;      
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF ID IS NOT NULL THEN
         --
         -- BUSCAMOS EL JUGADOR POR ID
         --
         OPEN RS FOR
           SELECT JUG_ID    ,
                  JUG_NOMBRE,
                  JUG_PAIS
             FROM JUGADOR
            WHERE JUG_ID = ID;     
         --   
      ELSE
        --
        IF PAIS IS NOT NULL THEN
          --
          -- BUSCAMOS POR PAIS
          --
          OPEN RS FOR
            SELECT JUG_ID    ,
                   JUG_NOMBRE,
                   JUG_PAIS
              FROM JUGADOR
             WHERE JUG_PAIS = PAIS;        
          --
        ELSE
          --
          -- BUSCAMOS TODOS LOS JUGADORES
          --
          OPEN RS FOR
            SELECT JUG_ID    ,
                   JUG_NOMBRE,
                   JUG_PAIS
              FROM JUGADOR;          
          --
        END IF;       
        --
      END IF;  
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );   
      --              
    END CONSULTA;
  --                      
END G_JUGADOR;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_JORNADA AS
  --
  -- /* Gestin de JORNADAS */
  --
  PROCEDURE ALTA(TEMPORADA    IN  JORNADA.JOR_TEMPORADA%TYPE  ,
                 COMPETICION  IN  JORNADA.JOR_COMPETICION%TYPE,
                 DESCRIPCION  IN  JORNADA.JOR_DESCRIPCION%TYPE,
                 RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO OUT NUMBER                         );
  --
  PROCEDURE BAJA(ID          IN  JORNADA.JOR_ID%TYPE            ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       );
  --
  PROCEDURE MODIFICAR(ID          IN  JORNADA.JOR_ID%TYPE            ,
                      DESCRIPCION IN  JORNADA.JOR_DESCRIPCION%TYPE ,
                      RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                      RESULTADO   OUT NUMBER                       );
  --
  PROCEDURE CONSULTA(ID          IN  JORNADA.JOR_ID%TYPE          ,
                     TEMPORADA   IN  JORNADA.JOR_TEMPORADA%TYPE   ,
                     COMPETICION IN  JORNADA.JOR_COMPETICION%TYPE ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                );
  --                      
END G_JORNADA;  
--
--
-- GESTION DE JORNADAS
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_JORNADA AS
  --
  --
  -- INSERTA UNA JORNADA EN EL SISTEMA
  --  
  PROCEDURE ALTA(TEMPORADA   IN  JORNADA.JOR_TEMPORADA%TYPE   ,
                 COMPETICION IN  JORNADA.JOR_COMPETICION%TYPE ,
                 DESCRIPCION IN  JORNADA.JOR_DESCRIPCION%TYPE ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT  NUMBER                      ) IS
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    EXISTE_JORNADA_T  NUMBER;
    --
    
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JORNADA.ALTA';
      P_ENTRADA_LOG     := 'TEMPORADA=' || TEMPORADA || ', COMPETICION=' || COMPETICION || ', DESCRIPCION=' || DESCRIPCION;
      --
      RESULTADO := 0;
      --
      IF TEMPORADA IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR LA TEMPORADA';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF COMPETICION IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR LA COMPETICION';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- COMPROBAMOS SI YA HAY UNA JORNADA CON LA MISMA DESCRIPCION EN ESA TEMPORADA
      --
      SELECT COUNT(JOR_ID) 
        INTO EXISTE_JORNADA_T
        FROM JORNADA
       WHERE JOR_TEMPORADA = TEMPORADA AND
             JOR_COMPETICION = COMPETICION AND
             JOR_DESCRIPCION = DESCRIPCION;
      --
      IF EXISTE_JORNADA_T > 0 THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. YA EXISTE UNA JORNADA CON ESA DESCRIPCION EN ESA TEMPORADA Y ESA COMPETICION';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      INSERT INTO JORNADA(JOR_TEMPORADA,
                          JOR_COMPETICION,
                          JOR_DESCRIPCION)
        VALUES (TEMPORADA  ,
                COMPETICION,
                DESCRIPCION );
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. JORNADA CREADA';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. YA HAY UNA JORNADA CON LA MISMA DESCRIPCION';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UN JORNADA DEL SISTEMA
    --
  PROCEDURE BAJA(ID          IN  JORNADA.JOR_ID%TYPE              ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO   OUT NUMBER                         ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JORNADA.BAJA';
      P_ENTRADA_LOG     := 'ID=' || ID    ;
      --
      RESULTADO := 0;                     
      --
      DELETE FROM JORNADA
       WHERE JOR_ID = ID; 
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. JORNADA ELIMINADA';
        --
      END IF;   
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      --                                  
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END BAJA;
    --
    --
    -- MODIFICA UNA JORNADA
    --
  PROCEDURE MODIFICAR(ID          IN  JORNADA.JOR_ID%TYPE          ,
                      DESCRIPCION IN  JORNADA.JOR_DESCRIPCION%TYPE ,
                      RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                      RESULTADO OUT NUMBER                       ) IS                        
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JORNADA.MODIFICAR';
      P_ENTRADA_LOG     := 'ID=' || ID || ', DESCRIPCION=' || DESCRIPCION;
      --
      RESULTADO := 0;                     
      --
      UPDATE JORNADA
         SET JOR_DESCRIPCION = DESCRIPCION
       WHERE JOR_ID = ID;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. JORNADA MODIFICADA';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      -- 
      WHEN DUP_VAL_ON_INDEX THEN
        --
        RESPUESTA := 'ERROR. YA HAY UNA JORNADA CON LA MISMA DESCRIPCION';
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
        --              
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE JORNADAS
  --
  PROCEDURE CONSULTA(ID          IN  JORNADA.JOR_ID%TYPE          ,
                     TEMPORADA   IN  JORNADA.JOR_TEMPORADA%TYPE   , 
                     COMPETICION IN  JORNADA.JOR_COMPETICION%TYPE ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE    ;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE        ;
    --
    R_LOG             NUMBER;
    --
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JORNADA.CONSULTA';
      P_ENTRADA_LOG     := 'ID=' || ID || 'TEMPORADA=' || TEMPORADA || 'COMPETICION=' || COMPETICION;      
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF ID IS NOT NULL THEN
         --
         -- BUSCAMOS LA JORNADA POR ID
         --
         OPEN RS FOR
           SELECT JOR_ID         ,
                  JOR_TEMPORADA  ,
                  JOR_COMPETICION,
                  JOR_DESCRIPCION
             FROM JORNADA
            WHERE JOR_ID = ID;     
         --   
      ELSE
        --
        IF COMPETICION IS NULL AND 
           TEMPORADA   IS NULL THEN
          --
          -- BUSCAMOS POR COMPETICION 
          --
          OPEN RS FOR
            SELECT JOR_ID         ,
                   JOR_TEMPORADA  ,
                   JOR_COMPETICION,
                   JOR_DESCRIPCION
              FROM JORNADA;
          --
        ELSE
          --
          IF COMPETICION IS NOT NULL AND 
             TEMPORADA   IS NOT NULL THEN
            --
            OPEN RS FOR
              SELECT JOR_ID         ,
                     JOR_TEMPORADA  ,
                     JOR_COMPETICION,
                     JOR_DESCRIPCION
                FROM JORNADA
               WHERE JOR_TEMPORADA   = TEMPORADA   AND
                     JOR_COMPETICION = COMPETICION;
            --
          ELSE
            --
            IF COMPETICION IS NOT NULL THEN
              --
              OPEN RS FOR
                SELECT JOR_ID         ,
                       JOR_TEMPORADA  ,
                       JOR_COMPETICION,
                       JOR_DESCRIPCION
                  FROM JORNADA
                 WHERE JOR_COMPETICION = COMPETICION;
              
              --
            ELSE
              --
              OPEN RS FOR
                SELECT JOR_ID         ,
                       JOR_TEMPORADA  ,
                       JOR_COMPETICION,
                       JOR_DESCRIPCION
                  FROM JORNADA
                 WHERE JOR_TEMPORADA   = TEMPORADA;
              --  
            END IF;
            --
          END IF;               
          --
        END IF;       
        --
      END IF;  
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );   
      --              
    END CONSULTA;
  --                      
END G_JORNADA;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_PARTIDO AS
  --
  -- /* Gestin de PARTIDOS */
  --
  PROCEDURE ALTA(JORNADA          IN PARTIDO.PART_JORNADA%TYPE     ,
                 EQUIPO_LOCAL     IN PARTIDO.PART_EQ_LOCAL%TYPE    ,
                 EQUIPO_VISITANTE IN PARTIDO.PART_EQ_VISITANTE%TYPE,
                 FECHA            IN PARTIDO.PART_FECHA%TYPE       ,
                 RESPUESTA        OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO        OUT NUMBER                       );
  --
  PROCEDURE BAJA(ID          IN  PARTIDO.PART_ID%TYPE         ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       );
  --
  PROCEDURE MODIFICAR(ID          IN  PARTIDO.PART_ID%TYPE           ,
                      FECHA       IN  PARTIDO.PART_FECHA%TYPE        ,
                      FINALIZADO  IN  PARTIDO.PART_FINALIZADO_SN%TYPE,
                      RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                      RESULTADO   OUT NUMBER                         );
  --
  PROCEDURE CONSULTA(ID          IN  PARTIDO.PART_ID%TYPE         ,
                     JORNADA     IN  PARTIDO.PART_JORNADA%TYPE    ,
                     EQUIPO      IN  PARTIDO.PART_EQ_LOCAL%TYPE   ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                );
  --                      
END G_PARTIDO;  
--
--
-- GESTION DE PARTIDOS
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_PARTIDO AS
  --
  -- INSERTA UN PARTIDO EN EL SISTEMA
  --  
  PROCEDURE ALTA(JORNADA          IN  PARTIDO.PART_JORNADA%TYPE     ,
                 EQUIPO_LOCAL     IN  PARTIDO.PART_EQ_LOCAL%TYPE    ,
                 EQUIPO_VISITANTE IN  PARTIDO.PART_EQ_VISITANTE%TYPE,
                 FECHA            IN  PARTIDO.PART_FECHA%TYPE       ,
                 RESPUESTA        OUT USR_OP.LOG.LOG_RESULTADO%TYPE ,
                 RESULTADO        OUT NUMBER                        ) IS
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    EXISTE_EQUIPO     NUMBER;
    --
    
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_PARTIDO.ALTA';
      P_ENTRADA_LOG     := 'JORNADA='       || JORNADA     || ', EQUIPO_LOCAL=' || EQUIPO_LOCAL ||
                           ', EQUIPO_VISITANTE=' || EQUIPO_VISITANTE || ', FECHA=' || FECHA;
      --
      RESULTADO := 0;
      --
      IF JORNADA IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR LA JORNADA';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF EQUIPO_LOCAL     IS NULL OR 
         EQUIPO_VISITANTE IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR LOS EQUIPOS';
        --
        RAISE EXCEPCION;
        --          
      END IF;
      --
      IF FECHA IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR LA FECHA';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- COMPROBAMOS QUE LOS DOS EQUIPOS EXISTEM
      --
      SELECT EQ_ID 
        INTO EXISTE_EQUIPO
        FROM EQUIPO
       WHERE EQ_ID = EQUIPO_LOCAL;
      --
      SELECT EQ_ID 
        INTO EXISTE_EQUIPO
        FROM EQUIPO
       WHERE EQ_ID = EQUIPO_VISITANTE;  
      --
      -- COMPROBAMOS QUE LOS EQUIPOS SON DISTINTOS
      --
      IF EQUIPO_LOCAL = EQUIPO_VISITANTE THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL EQUIPO LOCAL Y EL VISITANTE NO PUEDEN SER EL MISMO';
        --
        RAISE EXCEPCION;
        --
      END IF;    
      --
      -- COMPROBAMOS QUE NINGUNO DE LOS DOS EQUIPOS JUEGA OTRO PARTIDO EN LA MISMA JORNADA 
      -- EQUIPO LOCAL
      --
      EXISTE_EQUIPO := 0;
      --
      SELECT COUNT(PART_ID)
        INTO EXISTE_EQUIPO
        FROM PARTIDO 
       WHERE PART_JORNADA      = JORNADA      AND
            (PART_EQ_LOCAL     = EQUIPO_LOCAL OR
             PART_EQ_VISITANTE = EQUIPO_LOCAL);
      --
      IF EXISTE_EQUIPO > 0 THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL EQUIPO ' || EQUIPO_LOCAL || ' YA JUEGA OTRO PARTIDO EN ESA JORNADA';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- EQUIPO VISITANTE
      --
      EXISTE_EQUIPO := 0;
      --
      SELECT COUNT(PART_ID)
        INTO EXISTE_EQUIPO
        FROM PARTIDO 
       WHERE PART_JORNADA      = JORNADA      AND
            (PART_EQ_LOCAL     = EQUIPO_VISITANTE OR
             PART_EQ_VISITANTE = EQUIPO_VISITANTE);
      --
      IF EXISTE_EQUIPO > 0 THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL EQUIPO ' || EQUIPO_VISITANTE || ' YA JUEGA OTRO PARTIDO EN ESA JORNADA';
        --
        RAISE EXCEPCION;
        --
      END IF;

      --
      INSERT INTO PARTIDO(PART_JORNADA      ,
                          PART_EQ_LOCAL     ,
                          PART_EQ_VISITANTE ,
                          PART_FECHA        ,
                          PART_FINALIZADO_SN)
        VALUES (JORNADA         ,
                EQUIPO_LOCAL    ,
                EQUIPO_VISITANTE,
                FECHA           ,
                'N'             );
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. PARTIDO CREADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    WHEN NO_DATA_FOUND THEN
      --
      RESULTADO := -1;
      --
      RESPUESTA := 'ERROR. ALGUNO DE LOS EQUIPOS NO EXISTE';
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
  
      
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. YA HAY UNA JORNADA CON LA MISMA DESCRIPCION';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UN JORNADA DEL SISTEMA
    --
  PROCEDURE BAJA(ID          IN  PARTIDO.PART_ID%TYPE              ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO   OUT NUMBER                         ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_PARTIDO.BAJA';
      P_ENTRADA_LOG     := 'ID=' || ID    ;
      --
      RESULTADO := 0;                     
      --
      DELETE FROM PARTIDO
       WHERE PART_ID = ID; 
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. PARTIDO ELIMINADO';
        --
      END IF;   
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      --                                  
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END BAJA;
    --
    --
    -- MODIFICA UN PARTIDO
    --
  PROCEDURE MODIFICAR(ID          IN  PARTIDO.PART_ID%TYPE           ,
                      FECHA       IN  PARTIDO.PART_FECHA%TYPE        ,
                      FINALIZADO  IN  PARTIDO.PART_FINALIZADO_SN%TYPE,
                      RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                      RESULTADO   OUT NUMBER                         ) IS                        
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_PARTIDO.MODIFICAR';
      P_ENTRADA_LOG     := 'ID=' || ID || ', FECHA=' || FECHA || ', FINALIZADO_SN=' || FINALIZADO;
      --
      RESULTADO := 0;                     
      --
      UPDATE PARTIDO
         SET PART_FECHA         = FECHA     ,
             PART_FINALIZADO_SN = FINALIZADO
       WHERE PART_ID = ID;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. PARTIDO MODIFICADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      -- 
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE PARTIDOS
  --
  PROCEDURE CONSULTA(ID          IN  PARTIDO.PART_ID%TYPE         ,
                     JORNADA     IN  PARTIDO.PART_JORNADA%TYPE    ,
                     EQUIPO      IN  PARTIDO.PART_EQ_LOCAL%TYPE   ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE    ;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE        ;
    --
    R_LOG             NUMBER;
    --
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_PARTIDO.CONSULTA';
      P_ENTRADA_LOG     := 'ID=' || ID || 'JORNADA=' || JORNADA || 'EQUIPO=' || EQUIPO ;      
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF ID IS NOT NULL THEN
         --
         -- BUSCAMOS EL PARTIDO POR ID
         --
         OPEN RS FOR
           SELECT PART_ID           ,
                  PART_JORNADA      ,
                  PART_EQ_LOCAL     ,
                  PART_EQ_VISITANTE ,
                  PART_FECHA        ,
                  PART_FINALIZADO_SN
             FROM PARTIDO
            WHERE PART_ID = ID;     
         --   
      ELSE
        --
        IF JORNADA IS NULL AND 
           EQUIPO  IS NULL THEN
          --
          -- BUSCAMOS TODOS LOS PARTIDOS
          --
          OPEN RS FOR
            SELECT PART_ID           ,
                   PART_JORNADA      ,
                   PART_EQ_LOCAL     ,
                   PART_EQ_VISITANTE ,
                   PART_FECHA        ,
                   PART_FINALIZADO_SN
              FROM PARTIDO;
          --
        ELSE
          --
          IF JORNADA IS NOT NULL AND 
             EQUIPO  IS NOT NULL THEN
            --
            OPEN RS FOR
              SELECT PART_ID           ,
                     PART_JORNADA      ,
                     PART_EQ_LOCAL     ,
                     PART_EQ_VISITANTE ,
                     PART_FECHA        ,
                     PART_FINALIZADO_SN
                FROM PARTIDO
               WHERE PART_JORNADA       = JORNADA    AND
                     (PART_EQ_LOCAL     = EQUIPO  OR
                      PART_EQ_VISITANTE = EQUIPO    ) ;
            --
          ELSE
            --
            IF JORNADA IS NOT NULL THEN
              --
              OPEN RS FOR
                SELECT PART_ID           ,
                       PART_JORNADA      ,
                       PART_EQ_LOCAL     ,
                       PART_EQ_VISITANTE ,
                       PART_FECHA        ,
                       PART_FINALIZADO_SN
                  FROM PARTIDO
                 WHERE PART_JORNADA = JORNADA;
              
              --
            ELSE
              --
              OPEN RS FOR
                SELECT PART_ID           ,
                       PART_JORNADA      ,
                       PART_EQ_LOCAL     ,
                       PART_EQ_VISITANTE ,
                       PART_FECHA        ,
                       PART_FINALIZADO_SN
                  FROM PARTIDO
                 WHERE PART_EQ_LOCAL      = EQUIPO  OR
                        PART_EQ_VISITANTE = EQUIPO;    
              --  
            END IF;
            --
          END IF;               
          --
        END IF;       
        --
      END IF;  
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );   
      --              
    END CONSULTA;
  --                      
END G_PARTIDO;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_JUG_EQ_TEMP AS
  --
  -- /* Gestin de Jugadores-Equipos-Temporadas */
  --
  PROCEDURE ALTA(JUGADOR    IN  JUG_EQ_TEMPORADA.JET_JUGADOR%TYPE  ,
                 EQUIPO     IN  JUG_EQ_TEMPORADA.JET_EQUIPO%TYPE   ,
                 TEMPORADA  IN  JUG_EQ_TEMPORADA.JET_TEMPORADA%TYPE,
                 RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE      ,
                 RESULTADO  OUT NUMBER                             );
  --
  PROCEDURE BAJA(JUGADOR    IN  JUG_EQ_TEMPORADA.JET_JUGADOR%TYPE  ,
                 EQUIPO     IN  JUG_EQ_TEMPORADA.JET_EQUIPO%TYPE   ,
                 TEMPORADA  IN  JUG_EQ_TEMPORADA.JET_TEMPORADA%TYPE,
                 RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE      ,
                 RESULTADO  OUT NUMBER                             );
  --
  PROCEDURE MODIFICAR(JUGADOR    IN  JUG_EQ_TEMPORADA.JET_JUGADOR%TYPE  ,
                      EQUIPO     IN  JUG_EQ_TEMPORADA.JET_EQUIPO%TYPE   ,
                      TEMPORADA  IN  JUG_EQ_TEMPORADA.JET_TEMPORADA%TYPE,
                      RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE      ,
                      RESULTADO  OUT NUMBER                             );
  --
  PROCEDURE CONSULTA(JUGADOR    IN  JUG_EQ_TEMPORADA.JET_JUGADOR%TYPE  ,
                     EQUIPO     IN  JUG_EQ_TEMPORADA.JET_EQUIPO%TYPE   ,
                     TEMPORADA  IN  JUG_EQ_TEMPORADA.JET_TEMPORADA%TYPE,
                     RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE      ,
                     RS         OUT SYS_REFCURSOR                      );
  --                      
END G_JUG_EQ_TEMP;  
--
--
-- GESTION DE JUGADORES-EQUIPOS-TEMPORADAS
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_JUG_EQ_TEMP AS
  --
  -- INSERTA UN PARTIDO EN EL SISTEMA
  --  
  PROCEDURE ALTA(JUGADOR    IN  JUG_EQ_TEMPORADA.JET_JUGADOR%TYPE  ,
                 EQUIPO     IN  JUG_EQ_TEMPORADA.JET_EQUIPO%TYPE   ,
                 TEMPORADA  IN  JUG_EQ_TEMPORADA.JET_TEMPORADA%TYPE,
                 RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE      ,
                 RESULTADO  OUT NUMBER                             ) IS
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    EXISTE            NUMBER;
    --
    
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JUG_EQ_TEMP.ALTA';
      P_ENTRADA_LOG     := 'JUGADOR=' || JUGADOR || ', EQUIPO=' || EQUIPO || ', TEMPORADA=' || TEMPORADA ;
      --
      RESULTADO := 0;
      --
      -- COMPROBAMOS QUE NO HAY PARAMETROS NULOS
      --
      IF JUGADOR IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL JUGADOR';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF EQUIPO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL EQUIPO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF TEMPORADA IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR LA TEMPORADA';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- COMPROBAMOS QUE EXISTE EL EQUIPO 
      --
      BEGIN
        --
        SELECT EQ_ID 
          INTO EXISTE
          FROM EQUIPO
         WHERE EQ_ID = EQUIPO;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL EQUIPO NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EXISTE EL JUGADOR 
      --
      BEGIN
        --
        SELECT JUG_ID 
          INTO EXISTE
          FROM JUGADOR
         WHERE JUG_ID = JUGADOR;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL JUGADOR NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EXISTE LA TEMPORADA
      --      
      BEGIN
        --
        SELECT TEMP_ID 
          INTO EXISTE
          FROM TEMPORADA
         WHERE TEMP_ID = TEMPORADA;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. LA TEMPORADA NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;        
      --
      --
      -- COMPROBAMOS QUE EL JUGADOR NO JUEGA EN OTRO EQUIPO EN LA MISMA TEMPORADA
      --
      --
      BEGIN
        --
        SELECT JET_EQUIPO
          INTO EXISTE
          FROM JUG_EQ_TEMPORADA 
         WHERE JET_TEMPORADA = TEMPORADA AND
               JET_JUGADOR   = JUGADOR   ;
        --
        IF EXISTE > 0 THEN
          --
          RESULTADO := -1;
          --
          RESPUESTA := 'ERROR. EL JUGADOR ' || JUGADOR || ' YA JUEGA OTRO EQUIPO EN ESA TEMPORADA';
          --
          RAISE EXCEPCION;
          --
        END IF;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        NULL;
        --
      END;    
      --
          --
      INSERT INTO JUG_EQ_TEMPORADA(JET_JUGADOR  ,
                                   JET_EQUIPO   ,
                                   JET_TEMPORADA)
        VALUES (JUGADOR  ,
                EQUIPO   ,
                TEMPORADA);
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. REGISTRO CREADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. REGISTRO DUPLICADO';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UN JUGADOR_EQUIPO_TEMPORADA
    --
  PROCEDURE BAJA(JUGADOR    IN  JUG_EQ_TEMPORADA.JET_JUGADOR%TYPE  ,
                 EQUIPO     IN  JUG_EQ_TEMPORADA.JET_EQUIPO%TYPE   ,
                 TEMPORADA  IN  JUG_EQ_TEMPORADA.JET_TEMPORADA%TYPE,
                 RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE      ,
                 RESULTADO  OUT NUMBER                             ) IS
    --
    EXCEPCION         EXCEPTION;
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    EXISTE            NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JUG_EQ_TEMP.BAJA';
      P_ENTRADA_LOG     := 'JUGADOR=' || JUGADOR || ', EQUIPO=' || EQUIPO || ', TEMPORADA=' || TEMPORADA ;
      --
      RESULTADO := 0;                     
      --
      --
      -- COMPROBAMOS QUE NO HAY PARAMETROS NULOS
      --
      IF JUGADOR IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL JUGADOR';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF EQUIPO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL EQUIPO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF TEMPORADA IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR LA TEMPORADA';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- COMPROBAMOS QUE EXISTE EL EQUIPO 
      --
      BEGIN
        --
        SELECT EQ_ID 
          INTO EXISTE
          FROM EQUIPO
         WHERE EQ_ID = EQUIPO;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL EQUIPO NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EXISTE EL JUGADOR 
      --
      BEGIN
        --
        SELECT JUG_ID 
          INTO EXISTE
          FROM JUGADOR
         WHERE JUG_ID = JUGADOR;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL JUGADOR NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EXISTE LA TEMPORADA
      --      
      BEGIN
        --
        SELECT TEMP_ID 
          INTO EXISTE
          FROM TEMPORADA
         WHERE TEMP_ID = TEMPORADA;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. LA TEMPORADA NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;        
      --
      -- COMPROBAMOS SI EL JUGADOR HA JUGADO EN ALGUN PARTIDO DE LA TEMPORADA CON EL EQUIPO
      --
      BEGIN
        --
        SELECT PART_ID
          INTO EXISTE
          FROM JUEGA  ,
               PARTIDO, 
               JORNADA
         WHERE JUE_JUGADOR        = JUGADOR AND
               JUE_PARTIDO        = PART_ID AND
              (PART_EQ_LOCAL      = EQUIPO  OR
               PART_EQ_VISITANTE  = EQUIPO) AND
               PART_JORNADA       = JOR_ID  AND
               JOR_TEMPORADA      = TEMPORADA;
        -- 
        IF EXISTE > 0 THEN
          --
          RESULTADO := -1;
          --
          RESPUESTA := 'ERROR. EL JUGADOR YA HA JUGADO ALGUN PARTIDO CON EL EQUIPO EN ESA TEMPORADA ';
          --
          RAISE EXCEPCION;
          --       
        END IF;          
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        NULL;
        --
      WHEN TOO_MANY_ROWS THEN    
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL JUGADOR YA HA JUGADO ALGUN PARTIDO CON EL EQUIPO EN ESA TEMPORADA ';
        --
        RAISE EXCEPCION;
        --       
      END;  
      --
      DELETE FROM JUG_EQ_TEMPORADA
       WHERE JET_JUGADOR   = JUGADOR  AND
             JET_EQUIPO    = EQUIPO   AND
             JET_TEMPORADA = TEMPORADA; 
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. REGISTRO ELIMINADO';
        --
      END IF;   
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
        
      --
    END BAJA;
    --
    --
    -- MODIFICA EL EQUIPO AL QUE PEERTENECE UN JUGADOR EN UNA TEMPORADA
    --
  PROCEDURE MODIFICAR(JUGADOR    IN  JUG_EQ_TEMPORADA.JET_JUGADOR%TYPE  ,
                      EQUIPO     IN  JUG_EQ_TEMPORADA.JET_EQUIPO%TYPE   ,
                      TEMPORADA  IN  JUG_EQ_TEMPORADA.JET_TEMPORADA%TYPE,
                      RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE      ,
                      RESULTADO  OUT NUMBER                             ) IS                        
    --
    EXCEPCION         EXCEPTION;
    
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    EXISTE            NUMBER;
    --
    EQUIPO_ACTUAL     JUG_EQ_TEMPORADA.JET_EQUIPO%TYPE;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JUG_EQ_TEMP.MODIFICAR';
      --
      P_ENTRADA_LOG     := 'JUGADOR=' || JUGADOR || ', EQUIPO=' || EQUIPO || ', TEMPORADA=' || TEMPORADA ;
      --
      RESULTADO := 0;                     
      --
      --
      -- COMPROBAMOS QUE NO HAY PARAMETROS NULOS
      --
      IF JUGADOR IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL JUGADOR';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF EQUIPO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL EQUIPO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF TEMPORADA IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR LA TEMPORADA';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- COMPROBAMOS QUE EXISTE EL EQUIPO 
      --
      BEGIN
        --
        SELECT EQ_ID 
          INTO EXISTE
          FROM EQUIPO
         WHERE EQ_ID = EQUIPO;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL EQUIPO NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EXISTE EL JUGADOR 
      --
      BEGIN
        --
        SELECT JUG_ID 
          INTO EXISTE
          FROM JUGADOR
         WHERE JUG_ID = JUGADOR;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL JUGADOR NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EXISTE LA TEMPORADA
      --      
      BEGIN
        --
        SELECT TEMP_ID 
          INTO EXISTE
          FROM TEMPORADA
         WHERE TEMP_ID = TEMPORADA;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. LA TEMPORADA NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;        
      --
      -- COMPROBAMOS SI EL JUGADOR HA JUGADO EN ALGUN PARTIDO DE LA TEMPORADA CON EL EQUIPO ACTUAL
      --
      BEGIN
        --
        SELECT JET_EQUIPO
          INTO EQUIPO_ACTUAL
          FROM JUG_EQ_TEMPORADA
         WHERE JET_JUGADOR   = JUGADOR  AND
               JET_TEMPORADA = TEMPORADA;            
        --
        SELECT PART_ID
          INTO EXISTE
          FROM JUEGA  ,
               PARTIDO, 
               JORNADA
         WHERE JUE_JUGADOR        = JUGADOR       AND
               JUE_PARTIDO        = PART_ID        AND
              (PART_EQ_LOCAL      = EQUIPO_ACTUAL  OR
               PART_EQ_VISITANTE  = EQUIPO_ACTUAL) AND
               PART_JORNADA       = JOR_ID  AND
               JOR_TEMPORADA      = TEMPORADA;
        -- 
        IF EXISTE > 0 THEN
          --
          RESULTADO := -1;
          --
          RESPUESTA := 'ERROR. EL JUGADOR YA HA JUGADO ALGUN PARTIDO CON EL EQUIPO EN ESA TEMPORADA ';
          --
          RAISE EXCEPCION;
          --       
        END IF;          
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        NULL;
        --
      WHEN TOO_MANY_ROWS THEN    
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL JUGADOR YA HA JUGADO ALGUN PARTIDO CON EL EQUIPO EN ESA TEMPORADA ';
        --
        RAISE EXCEPCION;
        --       
      END;  
      --
      UPDATE JUG_EQ_TEMPORADA
         SET JET_EQUIPO    = EQUIPO
       WHERE JET_JUGADOR   = JUGADOR  AND
             JET_TEMPORADA = TEMPORADA;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. REGISTRO MODIFICADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      
      --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE PARTIDOS
  --
  PROCEDURE CONSULTA(JUGADOR    IN  JUG_EQ_TEMPORADA.JET_JUGADOR%TYPE  ,
                     EQUIPO     IN  JUG_EQ_TEMPORADA.JET_EQUIPO%TYPE   ,
                     TEMPORADA  IN  JUG_EQ_TEMPORADA.JET_TEMPORADA%TYPE,
                     RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE      ,
                     RS         OUT SYS_REFCURSOR                      ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE    ;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE        ;
    --
    R_LOG             NUMBER;
    --
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JUG_EQ_TEMP.CONSULTA';
      P_ENTRADA_LOG     := 'JUGADOR=' || JUGADOR || ', EQUIPO=' || EQUIPO || ', TEMPORADA=' || TEMPORADA ;
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF JUGADOR   IS NOT NULL AND
         EQUIPO    IS NOT NULL AND 
         TEMPORADA IS NOT NULL THEN
         --
         -- BUSCAMOS EL REGISTRO
         --
         OPEN RS FOR
           SELECT JET_JUGADOR  ,
                  JET_EQUIPO   ,
                  JET_TEMPORADA
             FROM JUG_EQ_TEMPORADA
            WHERE JET_JUGADOR   = JUGADOR  AND
                  JET_EQUIPO    = EQUIPO   AND
                  JET_TEMPORADA = TEMPORADA;     
        --   
      ELSE
        --
        IF JUGADOR IS NOT NULL THEN
          --
          --
          -- BUSCAMOS TODOS LOS EQUIPOS EN LOS QUE HA JUGADO UN JUGADOR EN CADA TEMPORADA
          --
          OPEN RS FOR
            SELECT JET_JUGADOR  ,
                   JET_EQUIPO   ,
                   JET_TEMPORADA
              FROM JUG_EQ_TEMPORADA
             WHERE JET_JUGADOR   = JUGADOR;
          --
        ELSE
          --
          IF EQUIPO    IS NOT NULL AND
             TEMPORADA IS NOT NULL THEN 
            --
            -- BUSCAMOS LOS JUGADORES DE UN EQUIPO EN UNA TEMPORADA
            --
            OPEN RS FOR
              SELECT JET_JUGADOR  ,
                     JET_EQUIPO   ,
                     JET_TEMPORADA
                FROM JUG_EQ_TEMPORADA
               WHERE JET_EQUIPO    = EQUIPO   AND
                     JET_TEMPORADA = TEMPORADA;     
            -- 
          ELSE
            --
            --
            IF EQUIPO IS NOT NULL THEN
              --
              OPEN RS FOR
                SELECT JET_JUGADOR  ,
                       JET_EQUIPO   ,
                       JET_TEMPORADA
                  FROM JUG_EQ_TEMPORADA
                 WHERE JET_EQUIPO = EQUIPO;
              --
            ELSE     
              --
              IF TEMPORADA IS NOT NULL THEN
                --
                OPEN RS FOR
                  SELECT JET_JUGADOR  ,
                         JET_EQUIPO   ,
                         JET_TEMPORADA
                    FROM JUG_EQ_TEMPORADA
                   WHERE JET_TEMPORADA = TEMPORADA;                  
                --
              ELSE  
                --
                -- BUSCAMOS TODOS LOS REGISTROS
                --
                OPEN RS FOR
                  SELECT JET_JUGADOR  ,
                         JET_EQUIPO   ,
                         JET_TEMPORADA
                    FROM JUG_EQ_TEMPORADA;
                --
              END IF;
              --
            END IF;
            --      
          END IF;   
          --
        END IF;       
        --
      END IF;  
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );   
      --              
    END CONSULTA;
  --                      
END G_JUG_EQ_TEMP;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_JUEGA AS
  --
  -- /* Gestin de ALINEACIONES */
  --
  PROCEDURE ALTA(PARTIDO   IN  JUEGA.JUE_PARTIDO%TYPE       ,
                 JUGADOR   IN  JUEGA.JUE_JUGADOR%TYPE       ,
                 RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO OUT NUMBER                       );
  --
  PROCEDURE BAJA(PARTIDO   IN  JUEGA.JUE_PARTIDO%TYPE         ,
                 JUGADOR   IN  JUEGA.JUE_JUGADOR%TYPE         ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       );
  --
  PROCEDURE CONSULTA(PARTIDO     IN  JUEGA.JUE_PARTIDO%TYPE       ,
                     EQUIPO      IN  EQUIPO.EQ_ID%TYPE            ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                );
  --                      
END G_JUEGA;  
--
--
-- GESTION DE ALINEACIONES
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_JUEGA AS
  --
  --
  -- INSERTA UN JUGADOR DE UN PARTIDO
  --  
  PROCEDURE ALTA(PARTIDO   IN  JUEGA.JUE_PARTIDO%TYPE        ,
                 JUGADOR   IN  JUEGA.JUE_JUGADOR%TYPE        ,
                 RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO OUT NUMBER                       ) IS
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    EXISTE_EQUIPO     EQUIPO.EQ_ID%TYPE;
    --
    
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JUEGA.ALTA';
      P_ENTRADA_LOG     := 'PARTIDO=' || PARTIDO || ', JUGADOR=' || JUGADOR;
      --
      RESULTADO := 0;
      --
      IF PARTIDO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. HAY QUE INDICAR EL PARTIDO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF JUGADOR IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. HAY QUE INDICAR EL JUGADOR';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- SE COMPRUEBA QUE EL JUGADOR PERTENECE A ALGUNO DE LOS EQUIPOS QUE JUEGAN EL PARTIDO 
      -- EN LA TEMPORADA EN QUE SE JUEGA EL PARTIDO
      --
      SELECT JET_EQUIPO 
        INTO EXISTE_EQUIPO
        FROM JUG_EQ_TEMPORADA,
             PARTIDO         ,
             JORNADA    
       WHERE PART_ID       = PARTIDO       AND
             JOR_ID        = PART_JORNADA  AND
             JET_JUGADOR   = JUGADOR       AND
             JET_TEMPORADA = JOR_TEMPORADA AND      
            (JET_EQUIPO    = PART_EQ_LOCAL OR
             JET_EQUIPO    = PART_EQ_VISITANTE);
      --
      INSERT INTO JUEGA(JUE_PARTIDO,
                        JUE_JUGADOR )
        VALUES (PARTIDO,
                JUGADOR);
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. REGISTRO CREADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN NO_DATA_FOUND THEN
      --
      RESULTADO := -1;
      --
      RESPUESTA := 'ERROR. EL JUGADOR NO PERTENECE A NINGUNO DE LOS EQUIPOS';
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
      --
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. ESTE JUGADOR YA JUEGA EL PARTIDO';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UN JUGADOR DE UN PARTIDO
    --
  PROCEDURE BAJA(PARTIDO     IN  JUEGA.JUE_PARTIDO%TYPE       ,
                 JUGADOR     IN  JUEGA.JUE_JUGADOR%TYPE       ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       ) IS
    --
    EXCEPCION         EXCEPTION;
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JUEGA.BAJA';
      P_ENTRADA_LOG     := 'PARTIDO=' || PARTIDO || ', JUGADOR=' || JUGADOR;
      --
      RESULTADO := 0;                     
      --
      IF PARTIDO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. HAY QUE INDICAR EL PARTIDO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF JUGADOR IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. HAY QUE INDICAR EL JUGADOR';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      DELETE FROM JUEGA
       WHERE JUE_PARTIDO = PARTIDO AND
             JUE_JUGADOR = JUGADOR; 
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. REGISTRO ELIMINADO';
        --
      END IF;   
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --                                  
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END BAJA;
               
  --
  --
  -- CONSULTA DE ALINEACIONES
  --
  PROCEDURE CONSULTA(PARTIDO     IN  JUEGA.JUE_PARTIDO%TYPE       ,
                     EQUIPO      IN  EQUIPO.EQ_ID%TYPE            ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                ) IS
    --
    EXCEPCION         EXCEPTION;
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE    ;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE        ;
    --
    R_LOG             NUMBER;
    --
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_JUEGA.CONSULTA';
      P_ENTRADA_LOG     := 'PARTIDO=' || PARTIDO || ', EQUIPO=' || EQUIPO;
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF PARTIDO IS NULL THEN
        --
        RESPUESTA := 'ERROR. HAY QUE INDICAR EL PARTIDO';
        --
        RAISE EXCEPCION;
        --
      END IF;  
      --
      IF EQUIPO IS NULL THEN
        --
        OPEN RS FOR
          SELECT JUE_PARTIDO,
                 JUE_JUGADOR
            FROM JUEGA
           WHERE JUE_PARTIDO = PARTIDO;
        --
      ELSE
        --
        -- SE HA INDOCADO EL PARTIDO Y EL EQUIPO
        OPEN RS FOR
          SELECT JUE_PARTIDO,
                 JUE_JUGADOR
            FROM JUEGA           ,
                 JUG_EQ_TEMPORADA,
                 JORNADA         ,
                 PARTIDO
           WHERE JUE_PARTIDO       = PARTIDO       AND
                 JET_EQUIPO        = EQUIPO        AND
                 JET_TEMPORADA     = JOR_TEMPORADA AND
                 JET_JUGADOR       = JUE_JUGADOR   AND
                 JOR_ID            = PART_JORNADA  AND
                 PART_ID           = JUE_PARTIDO  AND                 
                (PART_EQ_LOCAL     = EQUIPO      OR
                 PART_EQ_VISITANTE = EQUIPO     );
        --  
      END IF;       
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 NULL             ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );   
      --              
    END CONSULTA;
  --                      
END G_JUEGA;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_GOL AS
  --
  -- /* Gestin de GOLES */
  --
  PROCEDURE ALTA(PARTIDO   IN  GOL.GOL_PARTIDO%TYPE         ,
                 EQUIPO    IN  GOL.GOL_EQUIPO%TYPE          ,
                 JUGADOR   IN  GOL.GOL_JUGADOR%TYPE         ,
                 TIEMPO    IN  GOL.GOL_TIEMPO%TYPE          ,
                 RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO OUT NUMBER                       );
  --
  PROCEDURE BAJA(PARTIDO     IN  GOL.GOL_PARTIDO%TYPE         ,
                 NUMERO      IN  GOL.GOL_NUMERO%TYPE          ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       );
  --
  PROCEDURE MODIFICAR(PARTIDO   IN  GOL.GOL_PARTIDO%TYPE         ,
                      NUMERO    IN  GOL.GOL_NUMERO%TYPE          ,
                      JUGADOR   IN  GOL.GOL_JUGADOR%TYPE         ,
                      TIEMPO    IN  GOL.GOL_TIEMPO%TYPE          ,
                      RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                      RESULTADO OUT NUMBER                       );
  --
  PROCEDURE CONSULTA(PARTIDO   IN  GOL.GOL_PARTIDO%TYPE         ,
                     EQUIPO    IN  GOL.GOL_EQUIPO%TYPE          ,
                     JUGADOR   IN  GOL.GOL_JUGADOR%TYPE         ,
                     RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS        OUT SYS_REFCURSOR                );
  --                      
END G_GOL;  
--
--
-- GESTION DE GOLES
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_GOL AS
  --
  --
  -- INSERTA UN GOL EN EL SISTEMA
  --  
  PROCEDURE ALTA(PARTIDO   IN  GOL.GOL_PARTIDO%TYPE         ,
                 EQUIPO    IN  GOL.GOL_EQUIPO%TYPE          ,
                 JUGADOR   IN  GOL.GOL_JUGADOR%TYPE         ,
                 TIEMPO    IN  GOL.GOL_TIEMPO%TYPE          ,
                 RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO OUT NUMBER                       ) IS
    --
    EXCEPCION         EXCEPTION;
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    NUMERO_GOL        GOL.GOL_NUMERO%TYPE;
    --
    EXISTE            NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_GOL.ALTA';
      P_ENTRADA_LOG     := 'PARTIDO=' || PARTIDO || ', EQUIPO=' || EQUIPO || ', JUGADOR=' || JUGADOR || ', TIEMPO=' || TIEMPO ;
      --
      RESULTADO := 0;
      --
      -- SE COMPRUEBA QUE NO HAY PARAMETROS NULOS
      --
      IF PARTIDO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL PARTIDO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF EQUIPO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL EQUIPO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF JUGADOR IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL JUGADOR';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF TIEMPO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL TIEMPO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- COMPROBAMOS QUE EL PARTIDO EXISTE
      --
      BEGIN
        --
        SELECT PART_ID 
          INTO EXISTE
          FROM PARTIDO
         WHERE PART_ID = PARTIDO;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL PARTIDO NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EL EQUIPO EXISTE
      --
      BEGIN
        --
        SELECT EQ_ID 
          INTO EXISTE
          FROM EQUIPO
         WHERE EQ_ID = EQUIPO;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL EQUIPO NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EL JUGADOR EXISTE
      --
      BEGIN
        --
        SELECT JUG_ID 
          INTO EXISTE
          FROM JUGADOR
         WHERE JUG_ID = JUGADOR;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL JUGADOR NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE TIEMPO ES '1T'  '2T'
      --
      IF (TIEMPO <> '1T') AND 
         (TIEMPO <> '2T') THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL VALOR DE TIEMPO ES INCORRECTO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- COMPROBAMOS QUE EL JUGADOR PERTENECE AL EQUIPO QUE MARCA EL GOL 
      -- ... Y QUE JUEGA EN EL PARTIDO    
      --
      BEGIN
        --
        SELECT JUE_JUGADOR 
          INTO EXISTE
          FROM JUG_EQ_TEMPORADA,
               JORNADA         ,
               PARTIDO         , 
               JUEGA           
         WHERE JUE_PARTIDO   = PARTIDO      AND
               JUE_JUGADOR   = JUGADOR      AND
               --
               PART_ID       = JUE_PARTIDO  AND
               --
               JOR_ID        = PART_JORNADA AND
               --
               JET_JUGADOR   = JUE_JUGADOR  AND
               JET_EQUIPO    = EQUIPO       AND
               JET_TEMPORADA = JOR_TEMPORADA;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL JUGADOR NO JUEGA EN EL PARTIDO EN EL EQUIPO QUE MARCA EL GOL';
        --
        RAISE EXCEPCION;
        --  
      END;
      --
      -- OBTENEMOS EL VALOR DE GOL_NUMERO
      --
      SELECT MAX(GOL_NUMERO) + 1
        INTO NUMERO_GOL
        FROM GOL
       WHERE GOL_PARTIDO = PARTIDO;
      --
      INSERT INTO GOL(GOL_PARTIDO,      
                      GOL_NUMERO ,
                      GOL_EQUIPO ,
                      GOL_JUGADOR,
                      GOL_TIEMPO )
        VALUES (PARTIDO   ,
                NUMERO_GOL,
                EQUIPO    ,
                JUGADOR   ,
                TIEMPO    );
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. GOL INSERTADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. YA HAY UN GOL CON EL NUMERO' || NUMERO_GOL || 'EN ESE PARTIDO';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UN GOL DEL SISTEMA
    --
  PROCEDURE BAJA(PARTIDO     IN  GOL.GOL_PARTIDO%TYPE         ,
                 NUMERO      IN  GOL.GOL_NUMERO%TYPE          ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       ) IS
    --
    EXCEPCION          EXCEPTION;
    --
    PROCEDIMIENTO_LOG  USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG      USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG              NUMBER;
    --
    PARTIDO_FINALIZADO CHAR(1);
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_GOL.BAJA';
      P_ENTRADA_LOG     := 'PARTIDO=' || PARTIDO || ', NUMERO=' || NUMERO;
      --
      RESULTADO := 0;                     
      --
      SELECT PART_FINALIZADO_SN
        INTO PARTIDO_FINALIZADO
        FROM PARTIDO
       WHERE PART_ID = PARTIDO;
      -- 
      IF PARTIDO_FINALIZADO = 'S' THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL PARTIDO YA HA FINALIZADO';
        --
        RAISE EXCEPCION;
        --
      END IF;        
      --
      DELETE FROM GOL
       WHERE GOL_PARTIDO = PARTIDO AND
             GOL_NUMERO  = NUMERO  ;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. PAIS ELIMINADO';
        --
      END IF;   
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );
      --
    WHEN NO_DATA_FOUND THEN
      --
      RESULTADO := -1;
      --
      RESPUESTA := 'ERROR. EL PARTIDO NO EXISTE';
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 NULL             ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );
      --                                  
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 NULL             ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      
      --
    END BAJA;
    --
    --
    -- MODIFICA UN GOL
    --
  PROCEDURE MODIFICAR(PARTIDO   IN  GOL.GOL_PARTIDO%TYPE         ,
                      NUMERO    IN  GOL.GOL_NUMERO%TYPE          ,
                      JUGADOR   IN  GOL.GOL_JUGADOR%TYPE         ,
                      TIEMPO    IN  GOL.GOL_TIEMPO%TYPE          ,
                      RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                      RESULTADO OUT NUMBER                       ) IS                        
    --
    EXCEPCION         EXCEPTION;
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    EXISTE            NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_GOL.MODIFICAR';
      P_ENTRADA_LOG     := 'PARTIDO=' || PARTIDO || ', NUMERO=' || NUMERO || ', JUGADOR=' || JUGADOR || ', TIEMPO=' || TIEMPO ;
      --
      RESULTADO := 0;
      --
      -- SE COMPRUEBA QUE NO HAY PARAMETROS NULOS
      --
      IF PARTIDO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL PARTIDO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF NUMERO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL NUMERO DE GOL';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF JUGADOR IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL JUGADOR';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF TIEMPO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL TIEMPO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- COMPROBAMOS QUE EL PARTIDO EXISTE
      --
      BEGIN
        --
        SELECT PART_ID 
          INTO EXISTE
          FROM PARTIDO
         WHERE PART_ID = PARTIDO;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL PARTIDO NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EL JUGADOR EXISTE
      --
      BEGIN
        --
        SELECT JUG_ID 
          INTO EXISTE
          FROM JUGADOR
         WHERE JUG_ID = JUGADOR;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL JUGADOR NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE TIEMPO ES '1T'  '2T'
      --
      IF (TIEMPO <> '1T') AND 
         (TIEMPO <> '2T') THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL VALOR DE TIEMPO ES INCORRECTO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- COMPROBAMOS QUE EL JUGADOR PERTENECE AL EQUIPO QUE MARCA EL GOL 
      -- ... Y QUE JUEGA EN EL PARTIDO    
      --
      BEGIN
        --
        SELECT JUE_JUGADOR 
          INTO EXISTE
          FROM JUG_EQ_TEMPORADA,
               JORNADA         ,
               PARTIDO         , 
               JUEGA           ,
               GOL
         WHERE GOL_PARTIDO   = PARTIDO      AND
               GOL_NUMERO    = NUMERO       AND
               JUE_PARTIDO   = GOL_PARTIDO  AND
               JUE_JUGADOR   = JUGADOR      AND
               --
               PART_ID       = JUE_PARTIDO  AND
               --
               JOR_ID        = PART_JORNADA AND
               --
               JET_JUGADOR   = JUE_JUGADOR  AND
               JET_EQUIPO    = GOL_EQUIPO   AND
               JET_TEMPORADA = JOR_TEMPORADA;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL JUGADOR NO JUEGA EN EL PARTIDO EN EL EQUIPO QUE MARCA EL GOL';
        --
        RAISE EXCEPCION;
        --  
      END;                   
      --
      UPDATE GOL
         SET GOL_JUGADOR = JUGADOR,
             GOL_TIEMPO  = TIEMPO
       WHERE GOL_PARTIDO = PARTIDO AND
             GOL_NUMERO  = NUMERO ;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. GOL MODIFICADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      
      --              
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      
      --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE GOLES
  --
  PROCEDURE CONSULTA(PARTIDO   IN  GOL.GOL_PARTIDO%TYPE         ,
                     EQUIPO    IN  GOL.GOL_EQUIPO%TYPE          ,
                     JUGADOR   IN  GOL.GOL_JUGADOR%TYPE         ,
                     RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS        OUT SYS_REFCURSOR                ) IS
    --
    EXCEPCION         EXCEPTION;
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE;
    --
    R_LOG             NUMBER;
    --
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_GOL.CONSULTA';
      P_ENTRADA_LOG     := 'PARTIDO=' || PARTIDO || ', EQUIPO=' || EQUIPO || ', JUGADOR=' || JUGADOR ;
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF PARTIDO IS NULL AND 
         EQUIPO  IS NULL AND
         JUGADOR IS NULL THEN
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR ALGUN PARAMETRO';
        --
      END IF;
      --    
      IF PARTIDO IS NULL THEN
        --
        IF EQUIPO IS NULL THEN
          --
          -- BUSCAMOS POR JUGADOR
          --
          OPEN RS FOR 
            SELECT GOL_PARTIDO,
                   GOL_NUMERO ,
                   GOL_EQUIPO ,
                   GOL_JUGADOR,
                   GOL_TIEMPO
              FROM GOL
             WHERE GOL_JUGADOR = JUGADOR;
          --
        ELSE
          --
          IF JUGADOR IS NULL THEN
            --  
            -- BUSCAMOS POR EQUIPO
            --
            OPEN RS FOR 
              SELECT GOL_PARTIDO,
                     GOL_NUMERO ,
                     GOL_EQUIPO ,
                     GOL_JUGADOR,
                     GOL_TIEMPO
                FROM GOL
               WHERE GOL_EQUIPO = EQUIPO;
            --
          ELSE
            --
            -- BUSCAMOS POR JUGADOR Y POR EQUIPO
            --
            OPEN RS FOR 
              SELECT GOL_PARTIDO,
                     GOL_NUMERO ,
                     GOL_EQUIPO ,
                     GOL_JUGADOR,
                     GOL_TIEMPO
                FROM GOL
               WHERE GOL_EQUIPO  = EQUIPO  AND
                     GOL_JUGADOR = JUGADOR ;
            --
          END IF;
          -- 
        END IF;
        --
      ELSE
        --
        -- PARTIDO NO ES NULO
        --
        IF EQUIPO IS NULL THEN
          --
          IF JUGADOR IS NULL THEN
            --
            -- BUSCAMOS POR PARTIDO
            --
            OPEN RS FOR 
              SELECT GOL_PARTIDO,
                     GOL_NUMERO ,
                     GOL_EQUIPO ,
                     GOL_JUGADOR,
                     GOL_TIEMPO
                FROM GOL
               WHERE GOL_PARTIDO = PARTIDO;
            --
          ELSE
            --
            -- BUSCAMOS POR PARTIDO Y JUGADOR
            --
            OPEN RS FOR 
              SELECT GOL_PARTIDO,
                     GOL_NUMERO ,
                     GOL_EQUIPO ,
                     GOL_JUGADOR,
                     GOL_TIEMPO
                FROM GOL
               WHERE GOL_PARTIDO = PARTIDO AND
                     GOL_JUGADOR = JUGADOR;
            --  
          END IF;  
          --
       ELSE
          --   
          -- PARTIDO Y EQUIPO NO SON NULOS
          --
          IF JUGADOR IS NULL THEN
            --
            -- BUSCAMOS POR PARTIDO Y EQUIPO
            --
            OPEN RS FOR 
              SELECT GOL_PARTIDO,
                     GOL_NUMERO ,
                     GOL_EQUIPO ,
                     GOL_JUGADOR,
                     GOL_TIEMPO
                FROM GOL
               WHERE GOL_PARTIDO = PARTIDO AND
                     GOL_EQUIPO  = EQUIPO  ;
            --
          ELSE
            --
            -- SE HAN INDICADO LOS TRES PARAMETROS
            --
            OPEN RS FOR 
              SELECT GOL_PARTIDO,
                     GOL_NUMERO ,
                     GOL_EQUIPO ,
                     GOL_JUGADOR,
                     GOL_TIEMPO
                FROM GOL
               WHERE GOL_PARTIDO = PARTIDO AND
                     GOL_EQUIPO  = EQUIPO  AND
                     GOL_JUGADOR = JUGADOR ;
            --
          END IF;    
          --
        END IF;                           
        --
      END IF;  
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 NULL             ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );
      --
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );   
      --              
  END CONSULTA;
  --                      
END G_GOL;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_TIPO_MODALIDAD AS
  --
  -- /* Gestin de TIPOS DE MODALIDADES */
  --
  PROCEDURE ALTA(DESCRIPCION    IN TIPO_MODALIDAD.TM_DESCRIPCION%TYPE   ,
                 TIPO_RESULTADO IN TIPO_MODALIDAD.TM_TIPO_RESULTADO%TYPE,
                 RESPUESTA      OUT USR_OP.LOG.LOG_RESULTADO%TYPE       ,
                 RESULTADO      OUT NUMBER                              );
  --
  PROCEDURE BAJA(ID          IN  TIPO_MODALIDAD.TM_ID%TYPE    ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       );
  --
  PROCEDURE MODIFICAR(ID             IN  TIPO_MODALIDAD.TM_ID%TYPE            ,
                      DESCRIPCION    IN  TIPO_MODALIDAD.TM_DESCRIPCION%TYPE   ,
                      TIPO_RESULTADO IN  TIPO_MODALIDAD.TM_TIPO_RESULTADO%TYPE,
                      RESPUESTA      OUT USR_OP.LOG.LOG_RESULTADO%TYPE        ,
                      RESULTADO      OUT NUMBER                               );
  --
  PROCEDURE CONSULTA(ID          IN  TIPO_MODALIDAD.TM_ID%TYPE            ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                );
  --                      
END G_TIPO_MODALIDAD;  
--
--
-- GESTION DE TIPOS DE MODALIDADES
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_TIPO_MODALIDAD AS
  --
  --
  -- INSERTA UN EQUIPO EN EL SISTEMA
  --  
  PROCEDURE ALTA(DESCRIPCION    IN TIPO_MODALIDAD.TM_DESCRIPCION%TYPE   ,
                 TIPO_RESULTADO IN TIPO_MODALIDAD.TM_TIPO_RESULTADO%TYPE,
                 RESPUESTA      OUT USR_OP.LOG.LOG_RESULTADO%TYPE       ,
                 RESULTADO      OUT NUMBER                              ) IS
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_TIPO_MODALIDAD.ALTA';
      P_ENTRADA_LOG     := 'DESCRIPCION=' || DESCRIPCION || ', TIPO_RESULTADO=' || TIPO_RESULTADO;
      --
      RESULTADO := 0;
      --
      IF TIPO_RESULTADO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL TIPO DE RESULTADO ES OBLIGATORIO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF TIPO_RESULTADO <> 'EQUIPO'    AND
         TIPO_RESULTADO <> 'JUGADOR'   AND
         TIPO_RESULTADO <> 'RESULTADO' AND
         TIPO_RESULTADO <> '1X2'       AND
         TIPO_RESULTADO <> 'N_GOLES'   THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL TIPO DE RESULTADO NO ES VLIDO';
        --
        RAISE EXCEPCION;
        --
      END IF;  
      --
      INSERT INTO TIPO_MODALIDAD(TM_DESCRIPCION   ,
                                 TM_TIPO_RESULTADO)
        VALUES (DESCRIPCION   ,
                TIPO_RESULTADO);
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. TIPO DE MODALIDAD CREADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
      
      --
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. YA HAY UN TIPO DE RESULTADO CON EL MISMO NOMBRE';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UN TIPO DE MODALIDAD
    --
  PROCEDURE BAJA(ID          IN  TIPO_MODALIDAD.TM_ID%TYPE    ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_TIPO_MODALIDAD.BAJA';
      P_ENTRADA_LOG     := 'ID=' || ID    ;
      --
      RESULTADO := 0;                     
      --
      DELETE FROM TIPO_MODALIDAD 
       WHERE TM_ID = ID; 
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. TIPO DE MODALIDAD ELIMINADA';
        --
      END IF;   
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      --                                  
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END BAJA;
    --
    --
    -- MODIFICA UN TIPO DE MODALIDAD
    --
  PROCEDURE MODIFICAR(ID             IN  TIPO_MODALIDAD.TM_ID%TYPE            ,
                      DESCRIPCION    IN  TIPO_MODALIDAD.TM_DESCRIPCION%TYPE   ,
                      TIPO_RESULTADO IN  TIPO_MODALIDAD.TM_TIPO_RESULTADO%TYPE,
                      RESPUESTA      OUT USR_OP.LOG.LOG_RESULTADO%TYPE        ,
                      RESULTADO      OUT NUMBER                               ) IS                        
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_TIPO_MODALIDAD.MODIFICAR';
      P_ENTRADA_LOG     := 'ID=' || ID || ', DESCRIPCION=' || DESCRIPCION || 'TIPO_RESULTADO=' || TIPO_RESULTADO;
      --
      RESULTADO := 0;                     
      --
      IF TIPO_RESULTADO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL TIPO DE RESULTADO ES OBLIGATORIO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF TIPO_RESULTADO <> 'EQUIPO'    AND
         TIPO_RESULTADO <> 'JUGADOR'   AND
         TIPO_RESULTADO <> 'RESULTADO' AND
         TIPO_RESULTADO <> '1X2'       AND
         TIPO_RESULTADO <> 'N_GOLES'   THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL TIPO DE RESULTADO NO ES VLIDO';
        --
        RAISE EXCEPCION;
        --
      END IF;  
      --
      UPDATE TIPO_MODALIDAD
         SET TM_DESCRIPCION = DESCRIPCION,
             TM_TIPO_RESULTADO = TIPO_RESULTADO
       WHERE TM_ID = ID;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. EQUIPO MODIFICADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      -- 
      WHEN DUP_VAL_ON_INDEX THEN
        --
        RESPUESTA := 'ERROR. YA HAY UN EQUIPO CON EL MISMO NOMBRE';
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
        --              
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE EQUIPOS
  --
  PROCEDURE CONSULTA(ID         IN  TIPO_MODALIDAD.TM_ID%TYPE    ,
                     RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS         OUT SYS_REFCURSOR                ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE;
    --
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_EQUIPO.CONSULTA';
      P_ENTRADA_LOG     := 'ID=' || ID ;   
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF ID IS NOT NULL THEN
         --
         -- BUSCAMOS EL EQUIPO POR ID
         --
         OPEN RS FOR
           SELECT TM_ID            ,
                  TM_DESCRIPCION   ,
                  TM_TIPO_RESULTADO
             FROM TIPO_MODALIDAD
            WHERE TM_ID = ID;
         --   
      ELSE
        --
        OPEN RS FOR
          SELECT TM_ID            ,
                 TM_DESCRIPCION   ,
                 TM_TIPO_RESULTADO
            FROM TIPO_MODALIDAD;
        --
      END IF;  
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );   
      --              
  END CONSULTA;
  --                      
END G_TIPO_MODALIDAD;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_MODALIDAD AS
  --
  -- /* Gestin de MODALIDADES */
  --
  PROCEDURE ALTA(DESCRIPCION IN  MODALIDAD.MOD_DESCRIPCION%TYPE,
                 TIPO        IN  MODALIDAD.MOD_TIPO%TYPE       ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE ,
                 RESULTADO   OUT NUMBER                        );
  --
  PROCEDURE BAJA(ID          IN  MODALIDAD.MOD_ID%TYPE        ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       );
  --
  PROCEDURE MODIFICAR(ID          IN  MODALIDAD.MOD_ID%TYPE         ,
                      DESCRIPCION IN  MODALIDAD.MOD_DESCRIPCION%TYPE,
                      TIPO        IN  MODALIDAD.MOD_TIPO%TYPE       ,
                      RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                      RESULTADO  OUT NUMBER                         );
  --
  PROCEDURE CONSULTA(ID          IN  MODALIDAD.MOD_ID%TYPE        ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                );
  --                      
END G_MODALIDAD;  
--
--
-- GESTION DE MODALIDADES
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_MODALIDAD AS
  --
  --
  -- INSERTA UNA MODALIDAD EN EL SISTEMA
  --  
  PROCEDURE ALTA(DESCRIPCION IN  MODALIDAD.MOD_DESCRIPCION%TYPE,
                 TIPO        IN  MODALIDAD.MOD_TIPO%TYPE       ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE ,
                 RESULTADO   OUT NUMBER                        ) IS
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_EQUIPO.ALTA';
      P_ENTRADA_LOG     := 'DESCRIPCION=' || DESCRIPCION || ', TIPO=' || TIPO;
      --
      RESULTADO := 0;
      --
      IF TIPO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'SE DEBE INDICAR EL TIPO DE MODALIDAD';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      INSERT INTO MODALIDAD(MOD_DESCRIPCION,
                            MOD_TIPO       )
        VALUES (DESCRIPCION,
                TIPO       );
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. MODALIDAD CREADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
      
      --
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. YA HAY UNA MODALIDAD CON EL MISMO NOMBRE';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UN EQUIPO DEL SISTEMA
    --
  PROCEDURE BAJA(ID          IN  MODALIDAD.MOD_ID%TYPE        ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_MODALIDAD.BAJA';
      P_ENTRADA_LOG     := 'ID=' || ID       ;
      --
      RESULTADO := 0;                     
      --
      DELETE FROM MODALIDAD
       WHERE MOD_ID = ID; 
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. MODALIDAD ELIMINADA';
        --
      END IF;   
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      --                                  
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END BAJA;
    --
    --
    -- MODIFICA UNA MODADLIDAD
    --
  PROCEDURE MODIFICAR(ID          IN  MODALIDAD.MOD_ID%TYPE         ,
                      DESCRIPCION IN  MODALIDAD.MOD_DESCRIPCION%TYPE,
                      TIPO        IN  MODALIDAD.MOD_TIPO%TYPE       ,
                      RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                      RESULTADO   OUT NUMBER                         ) IS                        
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_MODALIDAD.MODIFICAR';
      P_ENTRADA_LOG     := 'ID=' || ID || ', DESCRIPCION=' || DESCRIPCION || 'TIPO=' || TIPO;
      --
      RESULTADO := 0;                     
      --
      UPDATE MODALIDAD
         SET MOD_DESCRIPCION = DESCRIPCION,
             MOD_TIPO        = TIPO
       WHERE MOD_ID = ID;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. EQUIPO MODIFICADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      -- 
      WHEN DUP_VAL_ON_INDEX THEN
        --
        RESPUESTA := 'ERROR. YA HAY UNA MODALIDAD CON EL MISMO NOMBRE';
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
        --              
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE MODALIDADES
  --
  PROCEDURE CONSULTA(ID          IN  MODALIDAD.MOD_ID%TYPE        ,
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE;
    --
    R_LOG             NUMBER;
    --
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_MODALIDAD.CONSULTA';
      P_ENTRADA_LOG     := 'ID=' || ID ;      
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF ID IS NOT NULL THEN
         --
         -- BUSCAMOS EL EQUIPO POR ID
         --
         OPEN RS FOR
           SELECT MOD_ID         ,
                  MOD_DESCRIPCION,
                  MOD_TIPO
             FROM MODALIDAD
            WHERE MOD_ID = ID;     
         --   
      ELSE
        --
         OPEN RS FOR
           SELECT MOD_ID         ,
                  MOD_DESCRIPCION,
                  MOD_TIPO
             FROM MODALIDAD;
        --
      END IF;  
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );   
      --              
  END CONSULTA;
  --                      
END G_MODALIDAD;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_USUARIO AS
  --
  -- /* Gestin de USUARIOS */
  --
  PROCEDURE ALTA(ID               IN  USUARIO.USU_ID%TYPE              ,
                 NOMBRE           IN  USUARIO.USU_NOMBRE%TYPE          ,
                 FECHA_NACIMIENTO IN  USUARIO.USU_FECHA_NACIMIENTO%TYPE,
                 PAIS             IN  USUARIO.USU_PAIS%TYPE            ,
                 RESPUESTA        OUT USR_OP.LOG.LOG_RESULTADO%TYPE    ,
                 RESULTADO        OUT NUMBER                           );
  --
  PROCEDURE BAJA(ID          IN  USUARIO.USU_ID%TYPE          ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       );
  --
  PROCEDURE MODIFICAR(ID               IN  USUARIO.USU_ID%TYPE              ,
                      NOMBRE           IN  USUARIO.USU_NOMBRE%TYPE          ,
                      FECHA_NACIMIENTO IN  USUARIO.USU_FECHA_NACIMIENTO%TYPE,
                      PAIS             IN  USUARIO.USU_PAIS%TYPE            ,
                      RESPUESTA        OUT USR_OP.LOG.LOG_RESULTADO%TYPE    ,
                      RESULTADO        OUT NUMBER                           );
  --
  PROCEDURE CONSULTA(ID          IN  USUARIO.USU_ID%TYPE          ,
                     PAIS        IN  USUARIO.USU_PAIS%TYPE        , 
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                );
  --                      
END G_USUARIO;  
--
--
-- GESTION DE USUARIOS
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_USUARIO AS
  --
  --
  -- INSERTA UN USUARIO EN EL SISTEMA
  --  
  PROCEDURE ALTA(ID               IN  USUARIO.USU_ID%TYPE              ,
                 NOMBRE           IN  USUARIO.USU_NOMBRE%TYPE          ,
                 FECHA_NACIMIENTO IN  USUARIO.USU_FECHA_NACIMIENTO%TYPE,
                 PAIS             IN  USUARIO.USU_PAIS%TYPE            ,
                 RESPUESTA        OUT USR_OP.LOG.LOG_RESULTADO%TYPE    ,
                 RESULTADO        OUT NUMBER                           ) IS
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_USUARIO.ALTA';
      P_ENTRADA_LOG     := 'ID=' || ID || ', NOMBRE=' || NOMBRE || 'FECHA_NACIMIENTO=' || FECHA_NACIMIENTO || ', PAIS=' || PAIS;
      --
      RESULTADO := 0;
      --
      IF PAIS IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL PAIS';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      INSERT INTO USUARIO(USU_ID              ,
                          USU_NOMBRE          ,
                          USU_FECHA_NACIMIENTO,      
                          USU_PAIS            )
        VALUES (ID              ,
                NOMBRE          ,
                FECHA_NACIMIENTO,
                PAIS            );
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. USUARIO CREADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 NULL             ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. YA HAY UN USUARIO CON EL MISMO IDENTIFICADOR';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UN USUARIO DEL SISTEMA
    --
  PROCEDURE BAJA(ID          IN  USUARIO.USU_ID%TYPE            ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE  ,
                 RESULTADO   OUT NUMBER                         ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_USUARIO.BAJA';
      P_ENTRADA_LOG     := 'ID=' || ID    ;
      --
      RESULTADO := 0;                     
      --
      DELETE FROM USUARIO
       WHERE USU_ID = ID; 
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. USUARIO ELIMINADO';
        --
      END IF;   
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      --                                  
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTADO := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTADO        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END BAJA;
    --
    --
    -- MODIFICA UN USUARIO
    --
  PROCEDURE MODIFICAR(ID               IN  USUARIO.USU_ID%TYPE              ,
                      NOMBRE           IN  USUARIO.USU_NOMBRE%TYPE          ,
                      FECHA_NACIMIENTO IN  USUARIO.USU_FECHA_NACIMIENTO%TYPE,
                      PAIS             IN  USUARIO.USU_PAIS%TYPE            ,
                      RESPUESTA        OUT USR_OP.LOG.LOG_RESULTADO%TYPE    ,
                      RESULTADO        OUT NUMBER                           ) IS                        
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_USUARIO.MODIFICAR';
      P_ENTRADA_LOG     := 'ID=' || ID || ', NOMBRE=' || NOMBRE || ', FECHA_NACIMIENTO=' || FECHA_NACIMIENTO || ', PAIS=' || PAIS;
      --
      RESULTADO := 0;                     
      --
      UPDATE USUARIO
         SET USU_NOMBRE           = NOMBRE          ,
             USU_FECHA_NACIMIENTO = FECHA_NACIMIENTO,
             USU_PAIS             = PAIS
       WHERE USU_ID               = ID;
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
        --
        RESULTADO := -1;
        --
      ELSE
        --
        RESPUESTA := 'OK. USUARIO MODIFICADO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            ); 
      --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE USUARIOS
  --
  PROCEDURE CONSULTA(ID          IN  USUARIO.USU_ID%TYPE          ,
                     PAIS        IN  USUARIO.USU_PAIS%TYPE        , 
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE    ;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE        ;
    --
    R_LOG             NUMBER;
    --
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_USUARIO.CONSULTA';
      P_ENTRADA_LOG     := 'ID=' || ID || 'PAIS=' || PAIS;      
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF ID IS NOT NULL THEN
         --
         -- BUSCAMOS EL USUARIO POR ID
         --
         OPEN RS FOR
           SELECT USU_ID              ,
                  USU_NOMBRE          ,
                  USU_FECHA_NACIMIENTO,
                  USU_PAIS
             FROM USUARIO
            WHERE USU_ID = ID;     
         --   
      ELSE
        --
        IF PAIS IS NOT NULL THEN
          --
          -- BUSCAMOS POR PAIS
          --
          OPEN RS FOR
            SELECT USU_ID              ,
                   USU_NOMBRE          ,
                   USU_FECHA_NACIMIENTO,
                   USU_PAIS
              FROM USUARIO
             WHERE USU_PAIS = PAIS;
          --
        ELSE
          --
          -- BUSCAMOS TODOS LOS USUARIOS
          --
          OPEN RS FOR
            SELECT USU_ID              ,
                   USU_NOMBRE          ,
                   USU_FECHA_NACIMIENTO,
                   USU_PAIS
              FROM USUARIO;
          --
        END IF;       
        --
      END IF;  
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );   
      --              
    END CONSULTA;
  --                      
END G_USUARIO;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_RESULTADO AS
  --
  -- /* Gestin de RESULTADOS */
  --
  PROCEDURE ALTA(PARTIDO      IN  RESULTADO.RES_PARTIDO%TYPE   ,
                 MODALIDAD    IN  RESULTADO.RES_MODALIDAD%TYPE ,
                 RE_RESULTADO IN  RESULTADO.RES_RESULTADO%TYPE ,
                 RESPUESTA    OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTAT     OUT NUMBER                       );
  --
  PROCEDURE BAJA(PARTIDO   IN  RESULTADO.RES_PARTIDO%TYPE   ,
                 MODALIDAD IN  RESULTADO.RES_MODALIDAD%TYPE ,
                 RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTAT  OUT NUMBER                       );
  --
  PROCEDURE MODIFICAR(PARTIDO      IN  RESULTADO.RES_PARTIDO%TYPE   ,
                      MODALIDAD    IN  RESULTADO.RES_MODALIDAD%TYPE ,
                      RE_RESULTADO IN  RESULTADO.RES_RESULTADO%TYPE ,
                      RESPUESTA    OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                      RESULTAT     OUT NUMBER                       );
  --
  PROCEDURE CONSULTA(PARTIDO     IN  RESULTADO.RES_PARTIDO%TYPE   ,
                     MODALIDAD   IN  RESULTADO.RES_MODALIDAD%TYPE , 
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                );
  --
  PROCEDURE COMPROBAR_RESULTADO(PARTIDO      IN  RESULTADO.RES_PARTIDO%TYPE    ,
                                MODALIDAD    IN  RESULTADO.RES_MODALIDAD%TYPE  ,
                                RE_RESULTADO IN  RESULTADO.RES_RESULTADO%TYPE  ,
                                RESULTAT     OUT NUMBER                        );
  --                            
END G_RESULTADO;  
--
--
-- GESTION DE RESULTADOS
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_RESULTADO AS
  --
  --
  -- INSERTA UN RESULTADO EN EL SISTEMA
  --  
  PROCEDURE ALTA(PARTIDO      IN  RESULTADO.RES_PARTIDO%TYPE   ,
                 MODALIDAD    IN  RESULTADO.RES_MODALIDAD%TYPE ,
                 RE_RESULTADO IN  RESULTADO.RES_RESULTADO%TYPE ,
                 RESPUESTA    OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTAT     OUT NUMBER                       ) IS
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    EXISTE            NUMBER;
    --
    
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_RESULTADO.ALTA';
      P_ENTRADA_LOG     := 'PARTIDO=' || PARTIDO || ', MODALIDAD=' || MODALIDAD || 'RE_RESULTADO=' || RE_RESULTADO;
      --
      RESULTAT := 0;
      --
      -- SE COMPRUEBA QUE NO HAY PARAMETROS NULOS
      --
      IF PARTIDO IS NULL THEN
        --
        RESULTAT := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL PARTIDO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF MODALIDAD IS NULL THEN
        --
        RESULTAT := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR LA MODALIDAD';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF RE_RESULTADO IS NULL THEN
        --
        RESULTAT := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL RESULTADO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- COMPROBAMOS QUE EXISTE EL PARTIDO 
      --
      BEGIN
        --
        SELECT PART_ID 
          INTO EXISTE
          FROM PARTIDO
         WHERE PART_ID = PARTIDO;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTAT := -1;
        --
        RESPUESTA := 'ERROR. EL PARTIDO NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EXISTE LA MODALIDAD 
      --
      BEGIN
        --
        SELECT MOD_ID 
          INTO EXISTE
          FROM MODALIDAD
         WHERE MOD_ID = MODALIDAD;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTAT := -1;
        --
        RESPUESTA := 'ERROR. LA MODALIDAD NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EL RESULTADO ES CORRECTO
      -- SI NO LO ES RESULTAT VALDR -1
      --
      COMPROBAR_RESULTADO(PARTIDO     ,
                          MODALIDAD   ,
                          RE_RESULTADO,
                          RESULTAT    );
      IF RESULTAT = 0 THEN                    
        --      
        INSERT INTO RESULTADO(RES_PARTIDO  ,
                              RES_MODALIDAD,
                              RES_RESULTADO)
          VALUES (PARTIDO      ,
                  MODALIDAD    ,
                  RE_RESULTADO );
        --
        IF SQL%ROWCOUNT = 0 THEN
          --
          RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
          --
          RESULTAT := -1;
          --
        ELSE
          --
          -- EL REGISTRO SE HA CREADO HAY QUE ACTUALIZAR TODAS LAS APUESTAS ACERTADAS
          --
          UPDATE APUESTA
             SET APU_ACERTADA_SN = 'S'
           WHERE APU_PARTIDO     = PARTIDO     AND
                 APU_MODALIDAD   = MODALIDAD   AND
                 APU_APUESTA     = RE_RESULTADO;
          --
          RESPUESTA := 'OK. RESULTADO CREADO';
          --
        END IF;  
        --
      ELSE
        --
        RESPUESTA := 'ERROR. EL RESULTADO NO ES VALIDO';
        --
      END IF;
      --  
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTAT         ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTAT := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTAT         ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. YA HAY UN RESULTADO PARA ESE PARTIDO Y ESA MODALIDAD';
      --
      RESULTAT := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTAT         ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTAT := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTAT         ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UN RESULTADO DEL SISTEMA
    --
  PROCEDURE BAJA(PARTIDO   IN  RESULTADO.RES_PARTIDO%TYPE   ,
                 MODALIDAD IN  RESULTADO.RES_MODALIDAD%TYPE ,
                 RESPUESTA OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTAT  OUT NUMBER                       ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_RESULTADO.BAJA';
      P_ENTRADA_LOG     := 'PARTIDO=' || PARTIDO || ', MODALIDAD=' || MODALIDAD    ;
      --
      RESULTAT := 0;                     
      --
      DELETE 
        FROM RESULTADO 
       WHERE RES_PARTIDO   = PARTIDO AND
             RES_MODALIDAD = MODALIDAD; 
      --
      IF SQL%ROWCOUNT = 0 THEN
        --
        RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
        --
        RESULTAT  := -1;
        --
      ELSE
        --
        -- ACTUALIZAMOS LAS APUESTAS AFECTADAS
        --
        UPDATE APUESTA
           SET APU_ACERTADA_SN = 'N'
         WHERE APU_PARTIDO     = PARTIDO   AND
               APU_MODALIDAD   = MODALIDAD ;
        --
        RESPUESTA := 'OK. RESULTADO ELIMINADO';
        --
      END IF;   
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTAT         ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
      --                                  
      WHEN OTHERS THEN
        --
        RESPUESTA := 'ERROR. ' || SQLERRM;
        --
        RESULTAT := -1;
        --
        G_LOG.ALTA(PROCEDIMIENTO_LOG,
                   P_ENTRADA_LOG    ,
                   RESULTAT        ,
                   RESPUESTA        ,
                   SYSDATE          ,
                   R_LOG            );  
        
      --
    END BAJA;
    --
    --
    -- MODIFICA UN RESULTADO
    --
  PROCEDURE MODIFICAR(PARTIDO      IN  RESULTADO.RES_PARTIDO%TYPE   ,
                      MODALIDAD    IN  RESULTADO.RES_MODALIDAD%TYPE ,
                      RE_RESULTADO IN  RESULTADO.RES_RESULTADO%TYPE ,
                      RESPUESTA    OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                      RESULTAT     OUT NUMBER                       ) IS                        
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    EXISTE            NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_RESULTADO.MODIFICAR';
      P_ENTRADA_LOG     := 'PARTIDO=' || PARTIDO || ', MODALIDAD=' || MODALIDAD || 'RE_RESULTADO=' || RE_RESULTADO;
      --
      RESULTAT := 0;
      --
      -- SE COMPRUEBA QUE NO HAY PARAMETROS NULOS
      --
      IF PARTIDO IS NULL THEN
        --
        RESULTAT := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL PARTIDO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF MODALIDAD IS NULL THEN
        --
        RESULTAT := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR LA MODALIDAD';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF RE_RESULTADO IS NULL THEN
        --
        RESULTAT := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL RESULTADO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- COMPROBAMOS QUE EXISTE EL PARTIDO 
      --
      BEGIN
        --
        SELECT PART_ID 
          INTO EXISTE
          FROM PARTIDO
         WHERE PART_ID = PARTIDO;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTAT := -1;
        --
        RESPUESTA := 'ERROR. EL PARTIDO NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EXISTE LA MODALIDAD 
      --
      BEGIN
        --
        SELECT MOD_ID 
          INTO EXISTE
          FROM MODALIDAD
         WHERE MOD_ID = MODALIDAD;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTAT := -1;
        --
        RESPUESTA := 'ERROR. LA MODALIDAD NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EL RESULTADO ES CORRECTO
      -- SI NO LO ES RESULTAT VALDR -1
      --
      COMPROBAR_RESULTADO(PARTIDO     ,
                          MODALIDAD   ,
                          RE_RESULTADO,
                          RESULTAT    );
      --
      IF RESULTAT = 0 THEN
        --                         
        UPDATE RESULTADO
           SET RES_RESULTADO = RE_RESULTADO
         WHERE RES_PARTIDO   = PARTIDO      AND
               RES_MODALIDAD = MODALIDAD;
        --
        IF SQL%ROWCOUNT = 0 THEN
          --
          RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
          --
          RESULTAT := -1;
          --
        ELSE
          --
          --ACTUALIZAMOS LAS APUESTAS AFECTADAS
          --
          UPDATE APUESTA
             SET APU_ACERTADA_SN = 'N'
           WHERE APU_PARTIDO     = PARTIDO   AND
                 APU_MODALIDAD   = MODALIDAD ;
          --
          UPDATE APUESTA
             SET APU_ACERTADA_SN = 'S'
           WHERE APU_PARTIDO     = PARTIDO     AND
                 APU_MODALIDAD   = MODALIDAD   AND
                 APU_APUESTA     = RE_RESULTADO;                 
          -- 
          RESPUESTA := 'OK. RESULTADO MODIFICADO';
          --
        END IF;  
        --
      ELSE
        --
        RESPUESTA := 'ERROR. EL RESULTADO APOSTADO NO ES VALIDO';
        --
      END IF;    
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTAT        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTAT := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTAT        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            ); 
      --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE RESULTADOS
  --
  PROCEDURE CONSULTA(PARTIDO     IN  RESULTADO.RES_PARTIDO%TYPE   ,
                     MODALIDAD   IN  RESULTADO.RES_MODALIDAD%TYPE , 
                     RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS          OUT SYS_REFCURSOR                ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE    ;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE        ;
    --
    R_LOG             NUMBER;
    --
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_RESULTADO.CONSULTA';
      P_ENTRADA_LOG     := 'PARTIDO=' || PARTIDO || ', MODALIDAD=' || MODALIDAD    ;
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF PARTIDO   IS NOT NULL AND
         MODALIDAD IS NOT NULL THEN
         --
         -- BUSCAMOS POR PARTIDO Y MODALIDAD
         --
         OPEN RS FOR
           SELECT RES_PARTIDO  ,
                  RES_MODALIDAD,
                  RES_RESULTADO 
             FROM RESULTADO
            WHERE RES_PARTIDO   = PARTIDO   AND
                  RES_MODALIDAD = MODALIDAD ;     
         --   
      ELSE
        --
        IF PARTIDO IS NOT NULL THEN
          --
          -- BUSCAMOS POR PARTIDO
          --
          OPEN RS FOR
            SELECT RES_PARTIDO  ,
                   RES_MODALIDAD,
                   RES_RESULTADO 
              FROM RESULTADO
             WHERE RES_PARTIDO = PARTIDO ;     
          --
        ELSE
          --
          IF MODALIDAD IS NOT NULL THEN
            --
            -- BUSCAMOS POR MODALIDAD
            --
            OPEN RS FOR
              SELECT RES_PARTIDO  ,
                     RES_MODALIDAD,
                     RES_RESULTADO 
                FROM RESULTADO
               WHERE RES_MODALIDAD   = MODALIDAD;
            --
          ELSE
            --
            -- DEVOLVEMOS TODOS LOS REGISTROS
            --
            OPEN RS FOR
              SELECT RES_PARTIDO  ,
                     RES_MODALIDAD,
                     RES_RESULTADO 
                FROM RESULTADO;
            --
          END IF;    
          --
        END IF;       
        --
      END IF;  
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );   
      --              
  END CONSULTA;
  --      
  PROCEDURE COMPROBAR_RESULTADO(PARTIDO      IN  RESULTADO.RES_PARTIDO%TYPE    ,
                                MODALIDAD    IN  RESULTADO.RES_MODALIDAD%TYPE  ,
                                RE_RESULTADO IN  RESULTADO.RES_RESULTADO%TYPE  ,
                                RESULTAT     OUT NUMBER                        ) IS
    --
    TIPO_MOD TIPO_MODALIDAD.TM_TIPO_RESULTADO%TYPE; 
    EXISTE   NUMBER;
    --
    PARTE_IZQUIERDA NUMBER;
    PARTE_DERECHA   NUMBER;
    ES_NUMERO       NUMBER;
    GUION           NUMBER;
    --
    --
    BEGIN
      --
      RESULTAT := 0;                                
      --
      -- COMPROBAMOS QUE EL PARTIDO EXISTE
      --
      SELECT PART_ID
        INTO EXISTE
        FROM PARTIDO 
       WHERE PART_ID = PARTIDO;
      --
      -- COMPROBAMOS QUE LA MODALIDAD EXISTE Y OBTENEMOS EL TIPO DE RESULTADO
      -- 
      SELECT TM_TIPO_RESULTADO 
        INTO TIPO_MOD
        FROM TIPO_MODALIDAD,
             MODALIDAD
       WHERE MOD_ID = MODALIDAD AND
             TM_ID  = MOD_TIPO;
      --
      CASE TIPO_MOD
        --
        WHEN 'EQUIPO' THEN
          --
          -- COMPROBAMOS QUE RE_RESULTADO SE CORRESPONDE CON EL ID DE UN EQUIPO
          --
          SELECT PART_ID
            INTO EXISTE
            FROM PARTIDO
           WHERE PART_ID           = PARTIDO                 AND
                (PART_EQ_LOCAL     = TO_NUMBER(RE_RESULTADO) OR
                 PART_EQ_VISITANTE = TO_NUMBER(RE_RESULTADO));
          --
        WHEN 'JUGADOR' THEN
          --
          -- COMPROBAMOS QUE RE_RESULTADO SE CORRESPONDE CON EL ID DE UN JUGADOR
          --
          SELECT JUG_ID 
            INTO EXISTE 
            FROM JUGADOR
           WHERE JUG_ID = TO_NUMBER(RE_RESULTADO);
          --
        WHEN 'RESULTADO' THEN  
          --
          -- COMPROBAMOS QUE RE_RESULTADO TIENE EL FORMATO 'NUMERO-NUMERO'
          --
          GUION := INSTR(RE_RESULTADO,'-');
          --
          IF GUION > 0 THEN
            --
            PARTE_IZQUIERDA := TO_NUMBER(SUBSTR(RE_RESULTADO, 1, GUION - 1));
            --
            PARTE_DERECHA   := TO_NUMBER(SUBSTR(RE_RESULTADO,GUION + 1, LENGTH(RE_RESULTADO)));
            --
          ELSE
            --
            RESULTAT := -1;
            --
          END IF;    
          --
        WHEN '1X2' THEN
          --
          IF RE_RESULTADO <> '1' AND
             RE_RESULTADO <> 'X' AND
             RE_RESULTADO <> '2' THEN
            --
            RESULTAT := -1; 
            --
          END IF;
          --  
        WHEN 'N_GOLES' THEN
          --
          ES_NUMERO := TO_NUMBER(RE_RESULTADO);
          --  
        --
      END CASE;
      --       
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESULTAT := -1;
      --
  END COMPROBAR_RESULTADO; 
  --                                              
END G_RESULTADO;
--
--
CREATE OR REPLACE PACKAGE USR_OP.G_APUESTA AS
  --
  -- /* Gestin de APUESTAS */
  --
  PROCEDURE ALTA(PARTIDO        IN  APUESTA.APU_PARTIDO%TYPE     ,
                 MODALIDAD      IN  APUESTA.APU_MODALIDAD%TYPE   ,
                 USUARIO        IN  APUESTA.APU_USUARIO%TYPE     ,
                 FECHA          IN  APUESTA.APU_FECHA%TYPE       ,
                 IMPORTE        IN  APUESTA.APU_IMPORTE%TYPE     ,  
                 VALOR_APUESTA  IN  APUESTA.APU_APUESTA%TYPE     ,    
                 RESPUESTA      OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO      OUT NUMBER                       );
  --
  PROCEDURE BAJA(ID          IN  APUESTA.APU_ID%TYPE    ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       );
  --
  PROCEDURE MODIFICAR(ID             IN  APUESTA.APU_ID%TYPE          ,
                      IMPORTE        IN  APUESTA.APU_IMPORTE%TYPE     ,
                      VALOR_APUESTA  IN  APUESTA.APU_APUESTA%TYPE     ,
                      RESPUESTA      OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                      RESULTADO      OUT NUMBER                       );
  --
  PROCEDURE CONSULTA(ID         IN  APUESTA.APU_ID%TYPE          ,
                     PARTIDO    IN  APUESTA.APU_PARTIDO%TYPE     ,
                     MODALIDAD  IN  APUESTA.APU_MODALIDAD%TYPE   ,
                     USUARIO    IN  APUESTA.APU_USUARIO%TYPE     ,
                     RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS         OUT SYS_REFCURSOR                );
  --                      
END G_APUESTA;  
--
--
-- GESTION DE APUESTAS
--
CREATE OR REPLACE PACKAGE BODY USR_OP.G_APUESTA AS
  --
  --
  -- INSERTA UNA APUESTA EN EL SISTEMA
  --  
  PROCEDURE ALTA(PARTIDO        IN  APUESTA.APU_PARTIDO%TYPE     ,
                 MODALIDAD      IN  APUESTA.APU_MODALIDAD%TYPE   ,
                 USUARIO        IN  APUESTA.APU_USUARIO%TYPE     ,
                 FECHA          IN  APUESTA.APU_FECHA%TYPE       ,
                 IMPORTE        IN  APUESTA.APU_IMPORTE%TYPE     ,  
                 VALOR_APUESTA  IN  APUESTA.APU_APUESTA%TYPE     ,    
                 RESPUESTA      OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO      OUT NUMBER                       ) IS
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    EXISTE            NUMBER;
    --
    
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_APUESTA.ALTA';
      P_ENTRADA_LOG     := 'PARTIDO=' || PARTIDO || ', MODALIDAD=' || MODALIDAD || ', USUARIO=' || USUARIO ||
                           ', FECHA=' || FECHA   || ', IMPORTE='   || IMPORTE   || ', APUESTA=' || VALOR_APUESTA;
      --
      RESULTADO := 0;
      --
      -- COMPROBAMOS QUE NO HAY PARAMETROS NULOS
      --
      IF PARTIDO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL PARTIDO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF MODALIDAD IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR LA MODALIDAD';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF USUARIO IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. SE DEBE INDICAR EL USUARIO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF FECHA IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. LA FECHA ES OBLIGATORIA';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF VALOR_APUESTA IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL RESULTADO ES OBLIGATORIO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      -- COMPROBAMOS QUE EXISTE EL PARTIDO
      --
      BEGIN
        --
        SELECT PART_ID 
          INTO EXISTE
          FROM PARTIDO
         WHERE PART_ID = PARTIDO;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL PARTIDO NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EXISTE LA MODALIDAD 
      --
      BEGIN
        --
        SELECT MOD_ID 
          INTO EXISTE
          FROM MODALIDAD
         WHERE MOD_ID = MODALIDAD;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. LA MODALIDAD NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      -- COMPROBAMOS QUE EXISTE EL USUARIO
      --
      BEGIN
        --
        SELECT 1 
          INTO EXISTE
          FROM USUARIO
         WHERE USU_ID = USUARIO;
        --
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL USUARIO NO EXISTE';
        --
        RAISE EXCEPCION;
        --
      END;
      --
      G_RESULTADO.COMPROBAR_RESULTADO(PARTIDO      ,
                          MODALIDAD    ,
                          VALOR_APUESTA,
                          RESULTADO    );
      --
      IF RESULTADO = 0 THEN                          
        --
        INSERT INTO APUESTA(APU_PARTIDO    ,
                            APU_MODALIDAD  ,
                            APU_USUARIO    ,
                            APU_FECHA      ,
                            APU_IMPORTE    ,
                            APU_APUESTA    ,
                            APU_ACERTADA_SN)
          VALUES (PARTIDO      ,
                  MODALIDAD    ,
                  USUARIO      ,
                  FECHA        ,
                  IMPORTE      ,
                  VALOR_APUESTA,
                  'N'          );
        --
        IF SQL%ROWCOUNT = 0 THEN
          --
          RESPUESTA := 'ERROR. NO SE HA INSERTADO NINGUN REGISTRO';
          --
          RESULTADO := -1;
          --
        ELSE
          --
          RESPUESTA := 'OK. APUESTA CREADO';
          --
        END IF;  
        --
      ELSE  
        --
        RESPUESTA := 'ERROR. EL RESULTADO APOSTADO NO ES VALIDO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN EXCEPCION THEN
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
      
      --
    WHEN DUP_VAL_ON_INDEX THEN
      --
      RESPUESTA := 'ERROR. YA HAY UNA APUESTA CON EL MISMO ID';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --               
    WHEN OTHERS THEN 
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );                 
      --
    END ALTA;  
    -- 
    --
    -- ELIMINA UNA APUESTA
    --
  PROCEDURE BAJA(ID          IN  APUESTA.APU_ID%TYPE    ,
                 RESPUESTA   OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                 RESULTADO   OUT NUMBER                       ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    --
    FECHA_PARTIDO     DATE;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_APUESTA.BAJA';
      P_ENTRADA_LOG     := 'ID=' || ID    ;
      --
      RESULTADO := 0;                     
      --
      SELECT PART_FECHA 
        INTO FECHA_PARTIDO
        FROM PARTIDO,
             APUESTA
       WHERE APU_ID  = ID          AND
             PART_ID = APU_PARTIDO ;
      --
      -- SOLO DEJAMOS ELIMINAR SI LA FECHA DEL PARTIDO ES POSTERIOR A LA FECHA ACTUAL
      --
      IF FECHA_PARTIDO > SYSDATE THEN                   
        --
        DELETE FROM APUESTA 
         WHERE APU_ID = ID; 
        --
        IF SQL%ROWCOUNT = 0 THEN
          --
          RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
          --
          RESULTADO := -1;
          --
        ELSE
          --
          RESPUESTA := 'OK. APUESTA ELIMINADA';
          --
        END IF;   
        --
      ELSE
        --
        RESPUESTA := 'ERROR. EL PARTIDO YA SE HA JUGADO';
        --
        RESULTADO := -1;
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN NO_DATA_FOUND THEN
      --
      RESPUESTA := 'ERROR. NO SE HA ELIMINADO NINGUN REGISTRO';
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --                                   
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );      
      --
    END BAJA;
    --
    --
    -- MODIFICA UNA APUESTA
    --
  PROCEDURE MODIFICAR(ID             IN  APUESTA.APU_ID%TYPE          ,
                      IMPORTE        IN  APUESTA.APU_IMPORTE%TYPE     ,
                      VALOR_APUESTA  IN  APUESTA.APU_APUESTA%TYPE     ,
                      RESPUESTA      OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                      RESULTADO      OUT NUMBER                       ) IS                        
    --
    EXCEPCION         EXCEPTION;
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    R_LOG             NUMBER;
    PARTIDO_APUESTA   PARTIDO.PART_ID%TYPE;
    MODALIDAD_APUESTA MODALIDAD.MOD_ID%TYPE;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_APUESTA.MODIFICAR';
      P_ENTRADA_LOG     := 'ID=' || ID || ', IMPORTE=' || IMPORTE || 'VALOR_APUESTA=' || VALOR_APUESTA;
      --
      RESULTADO := 0;                     
      --
      IF IMPORTE IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL IMPORTE ES OBLIGATORIO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      IF VALOR_APUESTA IS NULL THEN
        --
        RESULTADO := -1;
        --
        RESPUESTA := 'ERROR. EL VALOR APOSTADO ES OBLIGATORIO';
        --
        RAISE EXCEPCION;
        --
      END IF;
      --
      SELECT APU_PARTIDO ,
             APU_MODALIDAD
        INTO PARTIDO_APUESTA  ,
             MODALIDAD_APUESTA
        FROM APUESTA
       WHERE APU_ID = ID;
      --
      G_RESULTADO.COMPROBAR_RESULTADO(PARTIDO_APUESTA  ,
                                      MODALIDAD_APUESTA,
                                      VALOR_APUESTA    ,
                                      RESULTADO        );
      --
      IF RESULTADO = 0 THEN                          
        --
        UPDATE APUESTA
           SET APU_IMPORTE = IMPORTE,
               APU_APUESTA = VALOR_APUESTA
         WHERE APU_ID = ID;
        --
        IF SQL%ROWCOUNT = 0 THEN
          --
          RESPUESTA := 'ERROR. NO SE HA MODIFICADO NINGUN REGISTRO';
          --
          RESULTADO := -1;
          --
        ELSE
          --
          RESPUESTA := 'OK. APUESTA MODIFICADA';
          --
        END IF;  
        --
      ELSE
        --
        RESPUESTA := 'ERROR. EL RESULTADO APOSTADO NO ES VALIDO';
        --
      END IF;  
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. ' || SQLERRM;
      --
      RESULTADO := -1;
      --
      G_LOG.ALTA(PROCEDIMIENTO_LOG,
                 P_ENTRADA_LOG    ,
                 RESULTADO        ,
                 RESPUESTA        ,
                 SYSDATE          ,
                 R_LOG            );  
      
    --
    END MODIFICAR;                      
  --
  --
  -- CONSULTA DE APUESTAS
  --
  PROCEDURE CONSULTA(ID         IN  APUESTA.APU_ID%TYPE          ,
                     PARTIDO    IN  APUESTA.APU_PARTIDO%TYPE     ,
                     MODALIDAD  IN  APUESTA.APU_MODALIDAD%TYPE   ,
                     USUARIO    IN  APUESTA.APU_USUARIO%TYPE     ,
                     RESPUESTA  OUT USR_OP.LOG.LOG_RESULTADO%TYPE,
                     RS         OUT SYS_REFCURSOR                ) IS
    --
    PROCEDIMIENTO_LOG USR_OP.LOG.LOG_PROCEDIMIENTO%TYPE;
    P_ENTRADA_LOG     USR_OP.LOG.LOG_P_ENTRADA%TYPE;
    FECHA_LOG         USR_OP.LOG.LOG_FECHA%TYPE;
    --
    R_LOG             NUMBER;
    --
    BEGIN
      --
      PROCEDIMIENTO_LOG := 'G_EQUIPO.CONSULTA';
      P_ENTRADA_LOG     := 'ID=' || ID ;   
      --
      RESPUESTA := 'OK';
      --
      FECHA_LOG := SYSDATE;
      --
      IF ID IS NOT NULL THEN
        --
        -- BUSCAMOS EL EQUIPO POR ID
        --
        OPEN RS FOR
          SELECT APU_ID,
                 APU_PARTIDO,
                 APU_MODALIDAD  ,
                 APU_USUARIO    ,
                 APU_FECHA      ,
                 APU_IMPORTE    ,
                 APU_APUESTA    ,
                 APU_ACERTADA_SN
            FROM APUESTA
           WHERE APU_ID = ID;
        --   
      ELSE
        --
        OPEN RS FOR
          SELECT APU_ID,
                 APU_PARTIDO,
                 APU_MODALIDAD  ,
                 APU_USUARIO    ,
                 APU_FECHA      ,
                 APU_IMPORTE    ,
                 APU_APUESTA    ,
                 APU_ACERTADA_SN
            FROM APUESTA
           WHERE APU_PARTIDO   = NVL(PARTIDO  , APU_PARTIDO  ) AND
                 APU_MODALIDAD = NVL(MODALIDAD, APU_MODALIDAD) AND
                 APU_USUARIO   = NVL(USUARIO  , APU_USUARIO  ) ;
        --
      END IF;  
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );
      --
    EXCEPTION
    WHEN OTHERS THEN
      --
      RESPUESTA := 'ERROR. SE HA PRODUCIDO UN ERROR: ' || SQLERRM;
      --
      USR_OP.G_LOG.ALTA(PROCEDIMIENTO_LOG,
                        P_ENTRADA_LOG    ,
                        NULL             ,
                        RESPUESTA        ,
                        FECHA_LOG        ,
                        R_LOG            );   
      --              
  END CONSULTA;
  --                      
END G_APUESTA;
--
--