--
ALTER SESSION SET CURRENT_SCHEMA = USR_DW;
--
CREATE OR REPLACE PACKAGE ETL AS
  --
  -- PAQUETE DE GESTIN DE DATOS DEL DATAWAREHOUSE
  -- REALIZA LA CARGA DE DATOS EN EL SISTEMA ESTADSTICO
  --
  -- DIMENSIONES
  --
  PROCEDURE CARGA_D_TEMPORADA;
  --
  PROCEDURE CARGA_D_COMPETICION;
  --
  PROCEDURE CARGA_D_EQUIPO;
  --
  PROCEDURE CARGA_D_JORNADA;
  --
  PROCEDURE CARGA_D_JUGADOR;
  --
  PROCEDURE CARGA_D_MODALIDAD;
  --
  PROCEDURE CARGA_D_RESULTADO;
  --
  PROCEDURE CARGA_D_USUARIO(INTERVALO IN NUMBER);
  --
  --
  -- HECHO
  --
  PROCEDURE CARGA_H_APUESTA;
  --
  --
  -- CARGA INICIAL
  --
  PROCEDURE CARGA_INICIAL;
  --
  PROCEDURE BORRA_TODO;
  --
END ETL;
--
CREATE OR REPLACE PACKAGE BODY ETL AS
  --
  -- PAQUETE DE GESTIN DE DATOS DEL DATAWAREHOUSE
  -- REALIZA LA CARGA DE DATOS EN EL SISTEMA ESTADSTICO
  --
  -- DIMENSIONES
  --
  PROCEDURE CARGA_D_TEMPORADA IS
    --
    BEGIN
      --
      INSERT INTO D_TEMPORADA
        SELECT TEMP_ID,
               TEMP_DESCRIPCION
          FROM USR_OP.TEMPORADA;
      --
    END CARGA_D_TEMPORADA;
  --
  PROCEDURE CARGA_D_COMPETICION IS
    --
    BEGIN
      --
      INSERT INTO D_COMPETICION
        SELECT COMP_ID,
               COMP_DESCRIPCION
          FROM USR_OP.COMPETICION;
      --
    END CARGA_D_COMPETICION;

  --
  PROCEDURE CARGA_D_EQUIPO IS
    --
    BEGIN
      --
      INSERT INTO D_EQUIPO
        SELECT EQ_ID,
               EQ_NOMBRE
          FROM USR_OP.EQUIPO;     
      --
	  INSERT INTO D_EQUIPO(EQ_ID ,
	                       NOMBRE)
        VALUES( 0,
                '-EQUIPO NO DEFINIDO-');		
	    
	  --
    END CARGA_D_EQUIPO;
  --
  PROCEDURE CARGA_D_JORNADA IS
    --
    BEGIN
      --
      INSERT INTO D_JORNADA
        SELECT JOR_ID,
               JOR_DESCRIPCION
          FROM USR_OP.JORNADA;
      --
    END CARGA_D_JORNADA;
  
  --
  PROCEDURE CARGA_D_JUGADOR IS
    --
    BEGIN
      --
      INSERT INTO D_JUGADOR
        SELECT JUG_ID,
               JUG_NOMBRE
          FROM USR_OP.JUGADOR;
      --
	  INSERT INTO D_JUGADOR(JUG_ID,
	                        NOMBRE)
	    VALUES( 0,
		        '-JUGADOR NO DEFINIDO-');
	  --			
    END CARGA_D_JUGADOR;
  --
  PROCEDURE CARGA_D_MODALIDAD IS
    --
    BEGIN
      --
      INSERT INTO D_MODALIDAD 
        SELECT MOD_ID           ,
               MOD_DESCRIPCION  ,
               TM_TIPO_RESULTADO
          FROM USR_OP.MODALIDAD     ,
               USR_OP.TIPO_MODALIDAD
         WHERE TM_ID = MOD_TIPO;    
      --
    END;
  --
  PROCEDURE CARGA_D_RESULTADO IS
    --
    BEGIN
      --
      INSERT INTO D_RESULTADO(RES_ID     ,
                              DESCRIPCION)
        VALUES ('S',
                'ACIERTO');
      --
      INSERT INTO D_RESULTADO(RES_ID     ,
                              DESCRIPCION)
        VALUES ('N',
                'FALLO');                                                                 
      --
    END;
  --
  PROCEDURE CARGA_D_USUARIO(INTERVALO NUMBER) IS
    --
    BEGIN
      --
      INSERT INTO D_USUARIO(USUARIO_ID,
                            EDAD      ,
                            TRAMO_EDAD,
                            NOMBRE    ,
                            PAIS      )
        SELECT DISTINCT
               USU_ID,
               -- EDAD
               FLOOR(MONTHS_BETWEEN(APU_FECHA           ,
                                    USU_FECHA_NACIMIENTO)/12),
               -- TRAMO DE EDAD                     
               TO_CHAR(FLOOR(FLOOR(MONTHS_BETWEEN(APU_FECHA, USU_FECHA_NACIMIENTO)/12)/INTERVALO)*INTERVALO) 
               || '-' || 
               TO_CHAR(FLOOR(FLOOR((MONTHS_BETWEEN(APU_FECHA, USU_FECHA_NACIMIENTO)/12)/INTERVALO)*INTERVALO) + INTERVALO), 
               USU_NOMBRE  ,
               PAIS_NOMBRE
          FROM USR_OP.USUARIO,
               USR_OP.APUESTA,
               USR_OP.PAIS
         WHERE APU_USUARIO = USU_ID   AND
               PAIS_ID     = USU_PAIS ;             
      --
    END CARGA_D_USUARIO;  
  --
  --
  -- HECHO
  --
  PROCEDURE CARGA_H_APUESTA IS   
    --
    V_USUARIO     H_APUESTA.USUARIO%TYPE    ;
    V_EDAD        D_USUARIO.EDAD%TYPE       ;
    V_TEMPORADA   H_APUESTA.TEMPORADA%TYPE  ;
    V_COMPETICION H_APUESTA.COMPETICION%TYPE;
    V_EQUIPO      H_APUESTA.EQUIPO%TYPE     ;
    V_JORNADA     H_APUESTA.JORNADA%TYPE    ;
    V_JUGADOR     H_APUESTA.JUGADOR%TYPE    ;
    --
    V_TIPO        VARCHAR2(30);
    --
    CURSOR CUR IS
      SELECT APU_ID         ,
             APU_PARTIDO    ,
             APU_MODALIDAD  ,
             APU_USUARIO    ,
             APU_FECHA      ,
             APU_IMPORTE    ,
             APU_APUESTA    ,
             APU_ACERTADA_SN
        FROM USR_OP.APUESTA;
    --    
    V_REG   CUR%ROWTYPE;   
    --
    BEGIN
      --
      OPEN CUR;
      --
      -- RECORREMOS EL CURSOR PARA AVERIGUAR LOS DATOS
      --
      LOOP
        --
        FETCH CUR INTO V_REG;
        EXIT WHEN CUR%NOTFOUND;
        --
        -- CALCULAMOS LA EDAD DEL USUARIO EN EL MOMENTO DE HACER LA APUESTA
        --
        SELECT FLOOR(MONTHS_BETWEEN(APU_FECHA, USU_FECHA_NACIMIENTO)/12)
          INTO V_EDAD
          FROM USR_OP.APUESTA,
               USR_OP.USUARIO
         WHERE APU_ID = V_REG.APU_ID     AND
               USU_ID = V_REG.APU_USUARIO   ;
        --
        -- BUSCAMOS EL ID DE LA DIMENSION D_USUARIO
        --
        SELECT USUARIO_DW_ID
          INTO V_USUARIO
          FROM D_USUARIO 
         WHERE USUARIO_ID = V_REG.APU_USUARIO AND
               EDAD       = V_EDAD               ;
        --
        -- BUSCAMOS LA TEMPORADA, LA JORNADA Y LA COMPETICIN
        --
        SELECT JOR_TEMPORADA  ,
               JOR_COMPETICION,
               JOR_ID    
          INTO V_TEMPORADA  ,
               V_COMPETICION,
               V_JORNADA
          FROM USR_OP.JORNADA,
               USR_OP.PARTIDO
         WHERE PART_ID = V_REG.APU_PARTIDO AND
               JOR_ID  = PART_JORNADA;  
        --
        -- BUSCAMOS EL EQUIPO Y EL JUGADOR
        --
        SELECT TM_TIPO_RESULTADO 
          INTO V_TIPO
          FROM USR_OP.TIPO_MODALIDAD,
               USR_OP.MODALIDAD
         WHERE MOD_ID = V_REG.APU_MODALIDAD AND
               TM_ID  = MOD_TIPO;
        --
        CASE V_TIPO 
        WHEN 'EQUIPO' THEN
          --
          V_EQUIPO  := TO_NUMBER(V_REG.APU_APUESTA);
          --
          V_JUGADOR := 0;
          --
        WHEN 'JUGADOR' THEN
          --
          V_JUGADOR := TO_NUMBER(V_REG.APU_APUESTA);
          --
          V_EQUIPO  := 0;
          --  
        ELSE
          --
          V_EQUIPO  := 0;     
          --
          V_JUGADOR := 0;         
          --
        END CASE;       
        --
        -- YA  TENEMOS TODOS LOS VALORES. PODEMOS HACER EL INSERT
        --
        INSERT
          INTO H_APUESTA (APU_ID     ,
                          USUARIO    ,
                          TEMPORADA  ,
                          COMPETICION,
                          EQUIPO     ,
                          MODALIDAD  ,
                          JORNADA    ,
                          JUGADOR    ,
                          IMPORTE    ,
                          ACERTADA_SN)
          VALUES (V_REG.APU_ID       ,
                  V_USUARIO          ,
                  V_TEMPORADA        ,
                  V_COMPETICION      ,
                  V_EQUIPO           ,
                  V_REG.APU_MODALIDAD,
                  V_JORNADA          ,
                  V_JUGADOR          ,
                  V_REG.APU_IMPORTE  ,
                  V_REG.APU_ACERTADA_SN);
                                            
        --
      END LOOP;
      --
    --EXCEPTION 
    --WHEN OTHERS THEN
      --
      NULL;
      --
    END CARGA_H_APUESTA;

  --
  --
  -- CARGA INICIAL
  --
  PROCEDURE CARGA_INICIAL IS
      --
    BEGIN
      --
      BORRA_TODO;
      --
      CARGA_D_TEMPORADA;
      --
      CARGA_D_COMPETICION;
      --
      CARGA_D_EQUIPO;
      --
      CARGA_D_JORNADA;
      --
      CARGA_D_JUGADOR;
      --
      CARGA_D_MODALIDAD;
      --
      CARGA_D_RESULTADO;
      --
      CARGA_D_USUARIO(5);
      --
      CARGA_H_APUESTA;
      --
    END CARGA_INICIAL;

  --
  PROCEDURE BORRA_TODO IS
      --
    BEGIN
      --
      -- BORRA TODOS LOS DATOS DE LAS TABLAS PARA PODER REALIAR UNA CARGA COMPLETA
      --
      DELETE FROM H_APUESTA;
      --
      DELETE FROM D_TEMPORADA;
      --
      DELETE FROM D_COMPETICION;
      --
      DELETE FROM D_EQUIPO;
      --
      DELETE FROM D_JORNADA;
      --
      DELETE FROM D_JUGADOR;
      --
      DELETE FROM D_RESULTADO;
      --
      DELETE FROM D_USUARIO;
      --
      DELETE FROM D_MODALIDAD;
      -- 
    END BORRA_TODO;

  --
END ETL;
--
